@@ -1,17 +1,6 @@
 /******************************************************************************
-
   This source file is part of the Avogadro project.
-
-  Copyright 2012 Kitware, Inc.
-
-  This source code is released under the New BSD License, (the "License").
-
-  Unless required by applicable law or agreed to in writing, software
-  distributed under the License is distributed on an "AS IS" BASIS,
-  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-  See the License for the specific language governing permissions and
-  limitations under the License.
-
+  This source code is released under the 3-Clause BSD License, (see "LICENSE").
 ******************************************************************************/
 
 #include "elements.h"
@@ -26,8 +15,7 @@
 
 using Avogadro::Core::isCustomElement;
 
-namespace Avogadro {
-namespace Core {
+namespace Avogadro::Core {
 
 // Handle custom element identifiers:
 namespace {
@@ -280,5 +268,4 @@ const unsigned char* Elements::color(unsigned char atomicNumber)
     return element_color[0];
 }
 
-} // end Core namespace
 } // end Avogadro namespace
