@@ -11,39 +11,44 @@
 #include "elements.h"
 #include "layermanager.h"
 #include "mesh.h"
+#include "neighborperceiver.h"
 #include "residue.h"
 #include "unitcell.h"
 
 #include <algorithm>
+#include <array>
 #include <cassert>
 #include <iostream>
 
-namespace Avogadro {
-namespace Core {
+namespace Avogadro::Core {
 
 using std::swap;
 
 Molecule::Molecule()
-  : m_basisSet(nullptr), m_unitCell(nullptr), m_graphDirty(false),
+  : m_basisSet(nullptr), m_unitCell(nullptr),
     m_layers(LayerManager::getMoleculeLayer(this))
-{}
+{
+  m_elements.reset();
+}
 
 Molecule::Molecule(const Molecule& other)
-  : m_data(other.m_data), m_customElementMap(other.m_customElementMap),
+  : m_data(other.m_data), m_partialCharges(other.m_partialCharges),
+    m_customElementMap(other.m_customElementMap), m_elements(other.m_elements),
     m_positions2d(other.m_positions2d), m_positions3d(other.m_positions3d),
     m_label(other.m_label), m_coordinates3d(other.m_coordinates3d),
     m_timesteps(other.m_timesteps), m_hybridizations(other.m_hybridizations),
     m_formalCharges(other.m_formalCharges), m_colors(other.m_colors),
     m_vibrationFrequencies(other.m_vibrationFrequencies),
-    m_vibrationIntensities(other.m_vibrationIntensities),
+    m_vibrationIRIntensities(other.m_vibrationIRIntensities),
+    m_vibrationRamanIntensities(other.m_vibrationRamanIntensities),
     m_vibrationLx(other.m_vibrationLx), m_selectedAtoms(other.m_selectedAtoms),
     m_meshes(std::vector<Mesh*>()), m_cubes(std::vector<Cube*>()),
     m_basisSet(other.m_basisSet ? other.m_basisSet->clone() : nullptr),
     m_unitCell(other.m_unitCell ? new UnitCell(*other.m_unitCell) : nullptr),
     m_residues(other.m_residues), m_graph(other.m_graph),
-    m_graphDirty(other.m_graphDirty), m_bondPairs(other.m_bondPairs),
     m_bondOrders(other.m_bondOrders), m_atomicNumbers(other.m_atomicNumbers),
-    m_layers(LayerManager::getMoleculeLayer(&other, this))
+    m_hallNumber(other.m_hallNumber),
+    m_layers(LayerManager::getMoleculeLayer(this))
 {
   // Copy over any meshes
   for (Index i = 0; i < other.meshCount(); ++i) {
@@ -56,43 +61,64 @@ Molecule::Molecule(const Molecule& other)
     Cube* c = addCube();
     *c = *other.cube(i);
   }
+
+  // Copy layers, if they exist
+  if (other.m_layers.maxLayer() > 0)
+    m_layers = LayerManager::getMoleculeLayer(&other, this);
+  else {
+    // make sure all the atoms are in the active layer
+    for (Index i = 0; i < atomCount(); ++i)
+      m_layers.addAtomToActiveLayer(i);
+  }
 }
 
 Molecule::Molecule(Molecule&& other) noexcept
-  : m_data(std::move(other.m_data)),
+  : m_data(other.m_data),
+    m_partialCharges(std::move(other.m_partialCharges)),
     m_customElementMap(std::move(other.m_customElementMap)),
-    m_positions2d(std::move(other.m_positions2d)),
-    m_positions3d(std::move(other.m_positions3d)),
-    m_label(std::move(other.m_label)),
-    m_coordinates3d(std::move(other.m_coordinates3d)),
-    m_timesteps(std::move(other.m_timesteps)),
-    m_hybridizations(std::move(other.m_hybridizations)),
-    m_formalCharges(std::move(other.m_formalCharges)),
-    m_colors(std::move(other.m_colors)),
-    m_vibrationFrequencies(std::move(other.m_vibrationFrequencies)),
-    m_vibrationIntensities(std::move(other.m_vibrationIntensities)),
-    m_vibrationLx(std::move(other.m_vibrationLx)),
+    m_elements(other.m_elements), m_positions2d(other.m_positions2d),
+    m_positions3d(other.m_positions3d),
+    m_label(other.m_label),
+    m_coordinates3d(other.m_coordinates3d),
+    m_timesteps(other.m_timesteps),
+    m_hybridizations(other.m_hybridizations),
+    m_formalCharges(other.m_formalCharges),
+    m_colors(other.m_colors),
+    m_vibrationFrequencies(other.m_vibrationFrequencies),
+    m_vibrationIRIntensities(other.m_vibrationIRIntensities),
+    m_vibrationRamanIntensities(other.m_vibrationRamanIntensities),
+    m_vibrationLx(other.m_vibrationLx),
     m_selectedAtoms(std::move(other.m_selectedAtoms)),
     m_meshes(std::move(other.m_meshes)), m_cubes(std::move(other.m_cubes)),
-    m_residues(std::move(other.m_residues)), m_graph(std::move(other.m_graph)),
-    m_graphDirty(std::move(other.m_graphDirty)),
-    m_bondPairs(std::move(other.m_bondPairs)),
-    m_bondOrders(std::move(other.m_bondOrders)),
-    m_atomicNumbers(std::move(other.m_atomicNumbers)),
-    m_layers(LayerManager::getMoleculeLayer(&other, this))
+    m_residues(other.m_residues), m_graph(other.m_graph),
+    m_bondOrders(other.m_bondOrders),
+    m_atomicNumbers(other.m_atomicNumbers),
+    m_hallNumber(other.m_hallNumber),
+    m_layers(LayerManager::getMoleculeLayer(this))
 {
   m_basisSet = other.m_basisSet;
   other.m_basisSet = nullptr;
 
   m_unitCell = other.m_unitCell;
   other.m_unitCell = nullptr;
+
+  // Copy the layers, only if they exist
+  if (other.m_layers.maxLayer() > 0)
+    m_layers = LayerManager::getMoleculeLayer(&other, this);
+  else {
+    // make sure all the atoms are in the active layer
+    for (Index i = 0; i < atomCount(); ++i)
+      m_layers.addAtomToActiveLayer(i);
+  }
 }
 
 Molecule& Molecule::operator=(const Molecule& other)
 {
   if (this != &other) {
     m_data = other.m_data;
+    m_partialCharges = other.m_partialCharges;
     m_customElementMap = other.m_customElementMap;
+    m_elements = other.m_elements;
     m_positions2d = other.m_positions2d;
     m_positions3d = other.m_positions3d;
     m_label = other.m_label;
@@ -102,15 +128,15 @@ Molecule& Molecule::operator=(const Molecule& other)
     m_formalCharges = other.m_formalCharges;
     m_colors = other.m_colors,
     m_vibrationFrequencies = other.m_vibrationFrequencies;
-    m_vibrationIntensities = other.m_vibrationIntensities;
+    m_vibrationIRIntensities = other.m_vibrationIRIntensities;
+    m_vibrationRamanIntensities = other.m_vibrationRamanIntensities;
     m_vibrationLx = other.m_vibrationLx;
     m_selectedAtoms = other.m_selectedAtoms;
     m_residues = other.m_residues;
     m_graph = other.m_graph;
-    m_graphDirty = other.m_graphDirty;
-    m_bondPairs = other.m_bondPairs;
     m_bondOrders = other.m_bondOrders;
     m_atomicNumbers = other.m_atomicNumbers;
+    m_hallNumber = other.m_hallNumber;
 
     clearMeshes();
 
@@ -132,9 +158,16 @@ Molecule& Molecule::operator=(const Molecule& other)
     m_basisSet = other.m_basisSet ? other.m_basisSet->clone() : nullptr;
     delete m_unitCell;
     m_unitCell = other.m_unitCell ? new UnitCell(*other.m_unitCell) : nullptr;
-  }
 
-  m_layers = LayerManager::getMoleculeLayer(&other, this);
+    // Copy the layers, only if they exist
+    if (other.m_layers.maxLayer() > 0)
+      m_layers = LayerManager::getMoleculeLayer(&other, this);
+    else {
+      // make sure all the atoms are in the active layer
+      for (Index i = 0; i < atomCount(); ++i)
+        m_layers.addAtomToActiveLayer(i);
+    }
+  }
 
   return *this;
 }
@@ -142,26 +175,28 @@ Molecule& Molecule::operator=(const Molecule& other)
 Molecule& Molecule::operator=(Molecule&& other) noexcept
 {
   if (this != &other) {
-    m_data = std::move(other.m_data);
+    m_data = other.m_data;
+    m_partialCharges = std::move(other.m_partialCharges);
     m_customElementMap = std::move(other.m_customElementMap);
-    m_positions2d = std::move(other.m_positions2d);
-    m_positions3d = std::move(other.m_positions3d);
-    m_label = std::move(other.m_label);
-    m_coordinates3d = std::move(other.m_coordinates3d);
-    m_timesteps = std::move(other.m_timesteps);
-    m_hybridizations = std::move(other.m_hybridizations);
-    m_formalCharges = std::move(other.m_formalCharges);
-    m_colors = std::move(other.m_colors);
-    m_vibrationFrequencies = std::move(other.m_vibrationFrequencies);
-    m_vibrationIntensities = std::move(other.m_vibrationIntensities);
-    m_vibrationLx = std::move(other.m_vibrationLx);
+    m_elements = other.m_elements;
+    m_positions2d = other.m_positions2d;
+    m_positions3d = other.m_positions3d;
+    m_label = other.m_label;
+    m_coordinates3d = other.m_coordinates3d;
+    m_timesteps = other.m_timesteps;
+    m_hybridizations = other.m_hybridizations;
+    m_formalCharges = other.m_formalCharges;
+    m_colors = other.m_colors;
+    m_vibrationFrequencies = other.m_vibrationFrequencies;
+    m_vibrationIRIntensities = other.m_vibrationIRIntensities;
+    m_vibrationRamanIntensities = other.m_vibrationRamanIntensities;
+    m_vibrationLx = other.m_vibrationLx;
     m_selectedAtoms = std::move(other.m_selectedAtoms);
-    m_residues = std::move(other.m_residues);
-    m_graph = std::move(other.m_graph);
-    m_graphDirty = std::move(other.m_graphDirty);
-    m_bondPairs = std::move(other.m_bondPairs);
-    m_bondOrders = std::move(other.m_bondOrders);
-    m_atomicNumbers = std::move(other.m_atomicNumbers);
+    m_residues = other.m_residues;
+    m_graph = other.m_graph;
+    m_bondOrders = other.m_bondOrders;
+    m_atomicNumbers = other.m_atomicNumbers;
+    m_hallNumber = other.m_hallNumber;
 
     clearMeshes();
     m_meshes = std::move(other.m_meshes);
@@ -176,16 +211,23 @@ Molecule& Molecule::operator=(Molecule&& other) noexcept
     delete m_unitCell;
     m_unitCell = other.m_unitCell;
     other.m_unitCell = nullptr;
-  }
 
-  m_layers = LayerManager::getMoleculeLayer(&other, this);
+    // Copy the layers, if they exist
+    if (other.m_layers.maxLayer() > 0)
+      m_layers = LayerManager::getMoleculeLayer(&other, this);
+    else {
+      // make sure all the atoms are in the active layer
+      for (Index i = 0; i < atomCount(); ++i)
+        m_layers.addAtomToActiveLayer(i);
+    }
+  }
 
   return *this;
 }
 
 Molecule::~Molecule()
 {
-  LayerManager::deleteMolecule(this);
+  // LayerManager::deleteMolecule(this);
   delete m_basisSet;
   delete m_unitCell;
   clearMeshes();
@@ -201,6 +243,34 @@ const Layer& Molecule::layer() const
   return m_layers;
 }
 
+void Molecule::setPartialCharges(const std::string& type, const MatrixX& value)
+{
+  if (value.size() != atomCount())
+    return;
+
+  m_partialCharges[type] = value;
+}
+
+MatrixX Molecule::partialCharges(const std::string& type) const
+{
+  auto search = m_partialCharges.find(type);
+  if (search != m_partialCharges.end()) {
+    return search->second; // value from the map
+  } else {
+    MatrixX charges(atomCount(), 1);
+    charges.fill(0.0);
+    return charges;
+  }
+}
+
+std::set<std::string> Molecule::partialChargeTypes() const
+{
+  std::set<std::string> types;
+  for (auto& it : m_partialCharges)
+    types.insert(it.first);
+  return types;
+}
+
 void Molecule::setData(const std::string& name, const Variant& value)
 {
   m_data.setValue(name, value);
@@ -293,11 +363,16 @@ void Molecule::setCustomElementMap(const Molecule::CustomElementMap& map)
 
 Molecule::AtomType Molecule::addAtom(unsigned char number)
 {
-  if (!m_graphDirty) {
-    m_graph.addVertex();
-  }
+  m_graph.addVertex();
   m_atomicNumbers.push_back(number);
+  // we're not going to easily handle custom elements
+  if (number <= element_count)
+    m_elements.set(number);
+  else
+    m_elements.set(element_count - 1); // custom element
+
   m_layers.addAtomToActiveLayer(atomCount() - 1);
+  m_partialCharges.clear();
   return AtomType(this, static_cast<Index>(atomCount() - 1));
 }
 
@@ -311,7 +386,7 @@ Molecule::AtomType Molecule::addAtom(unsigned char number, Vector3 position3d)
 
 void Molecule::swapBond(Index a, Index b)
 {
-  swap(m_bondPairs[a], m_bondPairs[b]);
+  m_graph.swapEdgeIndices(a, b);
   swap(m_bondOrders[a], m_bondOrders[b]);
 }
 void Molecule::swapAtom(Index a, Index b)
@@ -329,29 +404,7 @@ void Molecule::swapAtom(Index a, Index b)
     swap(m_colors[a], m_colors[b]);
 
   swap(m_atomicNumbers[a], m_atomicNumbers[b]);
-  for (auto& pair : m_bondPairs) {
-    auto oldPair = pair;
-    bool changed = false;
-    if (pair.first == a) {
-      pair.first = b;
-      changed = true;
-    } else if (pair.first == b) {
-      pair.first = a;
-      changed = true;
-    }
-    if (pair.second == a) {
-      pair.second = b;
-      changed = true;
-    } else if (pair.second == b) {
-      pair.second = a;
-      changed = true;
-    }
-
-    if (changed && !m_graphDirty) {
-      m_graph.removeEdge(oldPair.first, oldPair.second);
-      m_graph.addEdge(pair.first, pair.second);
-    }
-  }
+  m_graph.swapVertexIndices(a, b);
   m_layers.swapLayer(a, b);
 }
 
@@ -378,16 +431,30 @@ bool Molecule::removeAtom(Index index)
     m_selectedAtoms.pop_back();
   }
 
-  Index affectedIndex = static_cast<Index>(m_atomicNumbers.size() - 1);
-  m_atomicNumbers.swapAndPop(index);
+  m_partialCharges.clear();
   removeBonds(index);
-  if (!m_graphDirty) {
-    m_graph.removeVertex(index);
+
+  // before we remove, check if there's any other atom of this element
+  // (e.g., we removed the last oxygen)
+  auto elementToRemove = m_atomicNumbers[index];
+  bool foundAnother = false;
+  for (Index i = 0; i < atomCount(); ++i) {
+    if (i == index)
+      continue;
+
+    if (m_atomicNumbers[index] == elementToRemove) {
+      foundAnother = true;
+      break; // we're done
+    }
   }
-  // the bonds from back() now are in index, so we need to rebond it
-  rebondBond(index, affectedIndex);
+  if (!foundAnother)
+    m_elements.reset(elementToRemove);
+
+  m_atomicNumbers.swapAndPop(index);
+  m_graph.removeVertex(index);
+
   m_layers.removeAtom(index);
-  return true;
+
   return true;
 }
 
@@ -406,9 +473,9 @@ void Molecule::clearAtoms()
   m_colors.clear();
   m_atomicNumbers.clear();
   m_bondOrders.clear();
-  m_bondPairs.clear();
   m_graph.clear();
-  m_graphDirty = false;
+  m_partialCharges.clear();
+  m_elements.reset();
 }
 
 Molecule::AtomType Molecule::atom(Index index) const
@@ -424,15 +491,14 @@ Molecule::BondType Molecule::addBond(Index atom1, Index atom2,
   assert(atom2 < m_atomicNumbers.size());
   Index index = bond(atom1, atom2).index();
   if (index >= bondCount()) {
-    if (!m_graphDirty) {
-      m_graph.addEdge(atom1, atom2);
-    }
-    m_bondPairs.push_back(Molecule::makeBondPair(atom1, atom2));
+    m_graph.addEdge(atom1, atom2);
     m_bondOrders.push_back(order);
-    index = static_cast<Index>(m_bondPairs.size() - 1);
+    index = static_cast<Index>(m_graph.edgeCount() - 1);
   } else {
     m_bondOrders[index] = order;
   }
+  // any existing charges are invalidated
+  m_partialCharges.clear();
   return BondType(this, index);
 }
 
@@ -460,19 +526,9 @@ bool Molecule::removeBond(Index index)
 {
   if (index >= bondCount())
     return false;
-  if (!m_graphDirty) {
-    // mark dirty the graph O(n) only if is more efficient than remove an edge
-    // O(nlogn)
-    size_t n = atomCount();
-    size_t m = calcNlogN(m_graph.subgraphCount(m_bondPairs[index].first));
-    if (m < n) {
-      m_graph.removeEdge(m_bondPairs[index].first, m_bondPairs[index].second);
-    } else {
-      m_graphDirty = true;
-    }
-  }
+  m_graph.removeEdge(index);
   m_bondOrders.swapAndPop(index);
-  m_bondPairs.swapAndPop(index);
+  m_partialCharges.clear();
   return true;
 }
 
@@ -494,10 +550,9 @@ bool Molecule::removeBond(const AtomType& a, const AtomType& b)
 void Molecule::clearBonds()
 {
   m_bondOrders.clear();
-  m_bondPairs.clear();
   m_graph.removeEdges();
   m_graph.setSize(atomCount());
-  m_graphDirty = false;
+  m_partialCharges.clear();
 }
 
 Molecule::BondType Molecule::bond(Index index) const
@@ -520,15 +575,13 @@ Molecule::BondType Molecule::bond(Index atomId1, Index atomId2) const
   assert(atomId1 < atomCount());
   assert(atomId2 < atomCount());
 
-  std::pair<Index, Index> pair = Molecule::makeBondPair(atomId1, atomId2);
-  Array<std::pair<Index, Index>>::const_iterator iter =
-    std::find(m_bondPairs.begin(), m_bondPairs.end(), pair);
-
-  Index index = static_cast<Index>(std::distance(m_bondPairs.begin(), iter));
-
-  if (index >= bondCount())
-    return BondType();
-  return BondType(const_cast<Molecule*>(this), index);
+  const std::vector<Index>& edgeIndices = m_graph.edges(atomId1);
+  for (unsigned long index : edgeIndices) {
+    const std::pair<Index, Index>& pair = m_graph.endpoints(index);
+    if (pair.first == atomId2 || pair.second == atomId2)
+      return BondType(const_cast<Molecule*>(this), index);
+  }
+  return BondType();
 }
 
 Array<Molecule::BondType> Molecule::bonds(const AtomType& a)
@@ -543,12 +596,20 @@ Array<const Molecule::BondType*> Molecule::bonds(Index a) const
 {
   Array<const BondType*> atomBonds;
   if (a < atomCount()) {
-    for (Index i = 0; i < m_bondPairs.size(); ++i)
-      if (m_bondPairs[i].first == a || m_bondPairs[i].second == a) {
-        // work arround to consult bonds without breaking constantness
-        atomBonds.push_back(new BondType(const_cast<Molecule*>(this), i));
+    const std::vector<Index>& edgeIndices = m_graph.edges(a);
+    for (unsigned long index : edgeIndices) {
+      if (m_graph.endpoints(index).first == a ||
+          m_graph.endpoints(index).second == a) {
+        // work around to consult bonds without breaking constantness
+        atomBonds.push_back(new BondType(const_cast<Molecule*>(this), index));
       }
+    }
   }
+
+  std::sort(atomBonds.begin(), atomBonds.end(),
+            [](const BondType*& a, const BondType*& b) {
+              return a->index() < b->index();
+            });
   return atomBonds;
 }
 
@@ -556,12 +617,16 @@ Array<Molecule::BondType> Molecule::bonds(Index a)
 {
   Array<BondType> atomBonds;
   if (a < atomCount()) {
-    for (Index i = 0; i < bondCount(); ++i) {
-      auto bond = bondPair(i);
+    const std::vector<Index>& edgeIndices = m_graph.edges(a);
+    for (unsigned long index : edgeIndices) {
+      auto bond = bondPair(index);
       if (bond.first == a || bond.second == a)
-        atomBonds.push_back(BondType(this, i));
+        atomBonds.push_back(BondType(this, index));
     }
   }
+
+  std::sort(atomBonds.begin(), atomBonds.end(),
+            [](BondType& a, BondType& b) { return a.index() < b.index(); });
   return atomBonds;
 }
 
@@ -749,14 +814,24 @@ void Molecule::setVibrationFrequencies(const Array<double>& freq)
   m_vibrationFrequencies = freq;
 }
 
-Array<double> Molecule::vibrationIntensities() const
+Array<double> Molecule::vibrationIRIntensities() const
 {
-  return m_vibrationIntensities;
+  return m_vibrationIRIntensities;
 }
 
-void Molecule::setVibrationIntensities(const Array<double>& intensities)
+void Molecule::setVibrationIRIntensities(const Array<double>& intensities)
 {
-  m_vibrationIntensities = intensities;
+  m_vibrationIRIntensities = intensities;
+}
+
+Array<double> Molecule::vibrationRamanIntensities() const
+{
+  return m_vibrationRamanIntensities;
+}
+
+void Molecule::setVibrationRamanIntensities(const Array<double>& intensities)
+{
+  m_vibrationRamanIntensities = intensities;
 }
 
 Array<Vector3> Molecule::vibrationLx(int mode) const
@@ -771,25 +846,34 @@ void Molecule::setVibrationLx(const Array<Array<Vector3>>& lx)
   m_vibrationLx = lx;
 }
 
-// bond perception code ported from VTK's vtkSimpleBondPerceiver class
 void Molecule::perceiveBondsSimple(const double tolerance, const double min)
 {
   // check for coordinates
-  if (m_positions3d.size() != atomCount())
+  if (m_positions3d.size() != atomCount() || m_positions3d.size() < 2)
     return;
 
   // cache atomic radii
   std::vector<double> radii(atomCount());
+  double max_radius = 0.0;
   for (size_t i = 0; i < radii.size(); i++) {
     radii[i] = Elements::radiusCovalent(atomicNumber(i));
     if (radii[i] <= 0.0)
       radii[i] = 2.0;
+    if (radii[i] > max_radius)
+      max_radius = radii[i];
   }
 
+  float maxDistance = 2.0 * max_radius + tolerance;
+  auto neighborPerceiver = NeighborPerceiver(m_positions3d, maxDistance);
+
   // check for bonds
+  // O(n) average-case, O(n^2) worst-case
+  // note that the "worst case" here would need to be an invalid molecule
+  Array<Index> neighbors;
   for (Index i = 0; i < atomCount(); i++) {
     Vector3 ipos = m_positions3d[i];
-    for (Index j = i + 1; j < atomCount(); j++) {
+    neighborPerceiver.getNeighborsInclusiveInPlace(neighbors, ipos);
+    for (unsigned long j : neighbors) {
       double cutoff = radii[i] + radii[j] + tolerance;
       Vector3 jpos = m_positions3d[j];
       Vector3 diff = jpos - ipos;
@@ -810,8 +894,8 @@ void Molecule::perceiveBondsSimple(const double tolerance, const double min)
 
 void Molecule::perceiveBondsFromResidueData()
 {
-  for (Index i = 0; i < m_residues.size(); ++i) {
-    m_residues[i].resolveResidueBonds(*this);
+  for (auto & m_residue : m_residues) {
+    m_residue.resolveResidueBonds(*this);
   }
 }
 
@@ -908,11 +992,7 @@ bool Molecule::setBondPairs(const Array<std::pair<Index, Index>>& pairs)
 bool Molecule::setBondPair(Index bondId, const std::pair<Index, Index>& pair)
 {
   if (bondId < bondCount()) {
-    if (!m_graphDirty) {
-      m_graph.removeEdge(m_bondPairs[bondId].first, m_bondPairs[bondId].second);
-      m_graph.addEdge(pair.first, pair.second);
-    }
-    m_bondPairs[bondId] = pair;
+    m_graph.editEdgeInPlace(bondId, pair.first, pair.second);
     return true;
   }
   return false;
@@ -944,9 +1024,8 @@ bool Molecule::setBondOrder(Index bondId, unsigned char order)
 Index Molecule::atomCount(unsigned char number) const
 {
   Index count(0);
-  for (Array<unsigned char>::const_iterator it = m_atomicNumbers.begin();
-       it != m_atomicNumbers.end(); ++it) {
-    if (*it == number)
+  for (unsigned char m_atomicNumber : m_atomicNumbers) {
+    if (m_atomicNumber == number)
       ++count;
   }
   return count;
@@ -957,10 +1036,13 @@ bool Molecule::setAtomicNumbers(const Core::Array<unsigned char>& nums)
   if (nums.size() == atomCount()) {
     m_atomicNumbers = nums;
 
+    // update element mask
+    m_elements.reset();
     // update colors too
     if (nums.size() == m_colors.size()) {
       for (Index i = 0; i < nums.size(); ++i) {
-        m_colors[i] = Vector3ub(Elements::color(atomicNumber(i)));
+        m_colors[i] = Vector3ub(Elements::color(m_atomicNumbers[i]));
+        m_elements.set(m_atomicNumbers[i]);
       }
     }
 
@@ -974,6 +1056,12 @@ bool Molecule::setAtomicNumber(Index atomId, unsigned char number)
   if (atomId < atomCount()) {
     m_atomicNumbers[atomId] = number;
 
+    // recalculate the element mask
+    m_elements.reset();
+    for (unsigned char m_atomicNumber : m_atomicNumbers) {
+      m_elements.set(m_atomicNumber);
+    }
+
     // update colors too
     if (atomId < m_colors.size())
       m_colors[atomId] = Vector3ub(Elements::color(number));
@@ -985,10 +1073,8 @@ bool Molecule::setAtomicNumber(Index atomId, unsigned char number)
 
 bool Molecule::hasCustomElements() const
 {
-  for (Array<unsigned char>::const_iterator it = m_atomicNumbers.begin(),
-                                            itEnd = m_atomicNumbers.end();
-       it != itEnd; ++it) {
-    if (Core::isCustomElement(*it))
+  for (unsigned char m_atomicNumber : m_atomicNumbers) {
+    if (Core::isCustomElement(m_atomicNumber))
       return true;
   }
   return false;
@@ -998,26 +1084,23 @@ std::map<unsigned char, size_t> Molecule::composition() const
 {
   // A map of atomic symbols to their quantity.
   std::map<unsigned char, size_t> composition;
-  for (Array<unsigned char>::const_iterator it = m_atomicNumbers.begin(),
-                                            itEnd = m_atomicNumbers.end();
-       it != itEnd; ++it) {
-    ++composition[*it];
+  for (unsigned char m_atomicNumber : m_atomicNumbers) {
+    ++composition[m_atomicNumber];
   }
   return composition;
 }
 
 bool Molecule::removeBonds(Index atom)
 {
-  if (atom >= bondCount())
+  if (atom >= atomCount())
     return false;
-  Index i = 0;
-  while (i < m_bondPairs.size()) {
-    auto& bond = m_bondPairs[i];
-    if (bond.first == atom || bond.second == atom) {
-      removeBond(i);
-    } else {
-      ++i;
-    }
+
+  while (true) {
+    const std::vector<size_t>& bondList = m_graph.edges(atom);
+    if (!bondList.size())
+      break;
+    size_t bond = bondList[0];
+    removeBond(bond);
   }
   return true;
 }
@@ -1025,12 +1108,9 @@ bool Molecule::removeBonds(Index atom)
 Array<std::pair<Index, Index>> Molecule::getAtomBonds(Index index) const
 {
   Array<std::pair<Index, Index>> result;
-  for (auto& pair : m_bondPairs) {
-    if (pair.first == index) {
-      result.push_back(pair);
-    } else if (pair.second == index) {
-      result.push_back(pair);
-    }
+  const std::vector<Index>& edgeIndices = m_graph.edges(index);
+  for (unsigned long edgeIndice : edgeIndices) {
+    result.push_back(m_graph.endpoints(edgeIndice));
   }
   return result;
 }
@@ -1038,14 +1118,9 @@ Array<std::pair<Index, Index>> Molecule::getAtomBonds(Index index) const
 Array<unsigned char> Molecule::getAtomOrders(Index index) const
 {
   Array<unsigned char> result;
-  Index i = 0;
-  for (auto& pair : m_bondPairs) {
-    if (pair.first == index) {
-      result.push_back(m_bondOrders[i]);
-    } else if (pair.second == index) {
-      result.push_back(m_bondOrders[i]);
-    }
-    ++i;
+  const std::vector<Index>& edgeIndices = m_graph.edges(index);
+  for (unsigned long edgeIndice : edgeIndices) {
+    result.push_back(m_bondOrders[edgeIndice]);
   }
   return result;
 }
@@ -1060,36 +1135,6 @@ void Molecule::addBonds(const Array<std::pair<Index, Index>>& bonds,
   }
 }
 
-void Molecule::updateGraph() const
-{
-  if (!m_graphDirty)
-    return;
-  m_graphDirty = false;
-  m_graph.clear();
-  m_graph.setSize(atomCount());
-  typedef Array<std::pair<Index, Index>>::const_iterator IterType;
-  for (IterType it = m_bondPairs.begin(); it != m_bondPairs.end(); ++it) {
-    if (it->first < atomCount() && it->second < atomCount()) {
-      m_graph.addEdge(it->first, it->second);
-    }
-  }
-}
-
-void Molecule::rebondBond(Index newIndex, Index oldIndex)
-{
-  // nothing to do
-  if (newIndex == oldIndex)
-    return;
-  for (auto& pair : m_bondPairs) {
-    if (pair.first == oldIndex) {
-      pair.first = newIndex;
-    } else if (pair.second == oldIndex) {
-      pair.second = newIndex;
-    }
-  }
-  m_graphDirty = true;
-}
-
 std::list<Index> Molecule::getAtomsAtLayer(size_t layer)
 {
   std::list<Index> result;
@@ -1102,5 +1147,4 @@ std::list<Index> Molecule::getAtomsAtLayer(size_t layer)
   return result;
 }
 
-} // namespace Core
 } // namespace Avogadro
