@@ -22,8 +22,7 @@
 
 using json = nlohmann::json;
 
-namespace Avogadro {
-namespace Io {
+namespace Avogadro::Io {
 
 using std::string;
 using std::vector;
@@ -34,14 +33,11 @@ using Core::BasisSet;
 using Core::Bond;
 using Core::CrystalTools;
 using Core::Cube;
-using Core::Elements;
 using Core::GaussianSet;
 using Core::LayerData;
 using Core::LayerManager;
-using Core::lexicalCast;
 using Core::Molecule;
 using Core::Residue;
-using Core::split;
 using Core::Variant;
 
 CjsonFormat::CjsonFormat() = default;
@@ -60,8 +56,7 @@ bool setJsonKey(json& j, Molecule& m, const std::string& key)
 bool isNumericArray(json& j)
 {
   if (j.is_array() && j.size() > 0) {
-    for (unsigned int i = 0; i < j.size(); ++i) {
-      json v = j[i];
+    for (const auto& v : j) {
       if (!v.is_number()) {
         return false;
       }
@@ -74,8 +69,7 @@ bool isNumericArray(json& j)
 bool isBooleanArray(json& j)
 {
   if (j.is_array() && j.size() > 0) {
-    for (unsigned int i = 0; i < j.size(); ++i) {
-      json v = j[i];
+    for (const auto& v : j) {
       if (!v.is_boolean()) {
         return false;
       }
@@ -125,8 +119,8 @@ bool CjsonFormat::read(std::istream& file, Molecule& molecule)
   // This represents our minimal spec for a molecule - atoms that have an
   // atomic number.
   if (isNumericArray(atomicNumbers) && atomicNumbers.size() > 0) {
-    for (unsigned int i = 0; i < atomicNumbers.size(); ++i)
-      molecule.addAtom(atomicNumbers[i]);
+    for (auto & atomicNumber : atomicNumbers)
+      molecule.addAtom(atomicNumber);
   } else {
     appendError("Malformed array for in atoms.elements.number");
     return false;
@@ -152,6 +146,14 @@ bool CjsonFormat::read(std::istream& file, Molecule& molecule)
     }
   }
 
+  // formal charges
+  json formalCharges = atoms["formalCharges"];
+  if (formalCharges.is_array() && formalCharges.size() == atomCount) {
+    for (size_t i = 0; i < atomCount; ++i) {
+      molecule.atom(i).setFormalCharge(formalCharges[i]);
+    }
+  }
+
   // Check for coordinate sets, and read them in if found, e.g. trajectories.
   json coordSets = atoms["coords"]["3dSets"];
   if (coordSets.is_array() && coordSets.size()) {
@@ -200,6 +202,21 @@ bool CjsonFormat::read(std::istream& file, Molecule& molecule)
     }
   }
 
+  // Partial charges are optional, but if present should be loaded.
+  json partialCharges = atoms["partialCharges"];
+  if (partialCharges.is_object()) {
+    // keys are types, values are arrays of charges
+    for (auto& kv : partialCharges.items()) {
+      MatrixX charges(atomCount, 1);
+      if (isNumericArray(kv.value()) && kv.value().size() == atomCount) {
+        for (size_t i = 0; i < kv.value().size(); ++i) {
+          charges(i, 0) = kv.value()[i];
+        }
+        molecule.setPartialCharges(kv.key(), charges);
+      }
+    }
+  }
+
   // Bonds are optional, but if present should be loaded.
   json bonds = jsonRoot["bonds"];
   if (bonds.is_object() && isNumericArray(bonds["connections"]["index"])) {
@@ -220,8 +237,7 @@ bool CjsonFormat::read(std::istream& file, Molecule& molecule)
   // residues are optional, but should be loaded
   json residues = jsonRoot["residues"];
   if (residues.is_array()) {
-    for (unsigned int i = 0; i < residues.size(); ++i) {
-      json residue = residues[i];
+    for (auto residue : residues) {
       if (!residue.is_object())
         continue; // malformed
 
@@ -306,7 +322,7 @@ bool CjsonFormat::read(std::istream& file, Molecule& molecule)
   // Basis set is optional, if present read it in.
   json basisSet = jsonRoot["basisSet"];
   if (basisSet.is_object()) {
-    GaussianSet* basis = new GaussianSet;
+    auto* basis = new GaussianSet;
     basis->setMolecule(&molecule);
     // Gather the relevant pieces together so that they can be read in.
     json shellTypes = basisSet["shellTypes"];
@@ -351,22 +367,22 @@ bool CjsonFormat::read(std::istream& file, Molecule& molecule)
       json occupations = orbitals["occupations"];
       if (isNumericArray(occupations)) {
         std::vector<unsigned char> occs;
-        for (unsigned int i = 0; i < occupations.size(); ++i)
-          occs.push_back(static_cast<unsigned char>(occupations[i]));
+        for (auto & occupation : occupations)
+          occs.push_back(static_cast<unsigned char>(occupation));
         basis->setMolecularOrbitalOccupancy(occupations);
       }
       json energies = orbitals["energies"];
       if (isNumericArray(energies)) {
         std::vector<double> energyArray;
-        for (unsigned int i = 0; i < energies.size(); ++i)
-          energyArray.push_back(static_cast<double>(energies[i]));
+        for (auto & energie : energies)
+          energyArray.push_back(static_cast<double>(energie));
         basis->setMolecularOrbitalEnergy(energyArray);
       }
       json numbers = orbitals["numbers"];
       if (isNumericArray(numbers)) {
         std::vector<unsigned int> numArray;
-        for (unsigned int i = 0; i < numbers.size(); ++i)
-          numArray.push_back(static_cast<unsigned int>(numbers[i]));
+        for (auto & number : numbers)
+          numArray.push_back(static_cast<unsigned int>(number));
         basis->setMolecularOrbitalNumber(numArray);
       }
       json moCoefficients = orbitals["moCoefficients"];
@@ -374,17 +390,17 @@ bool CjsonFormat::read(std::istream& file, Molecule& molecule)
       json moCoefficientsB = orbitals["betaCoefficients"];
       if (isNumericArray(moCoefficients)) {
         std::vector<double> coeffs;
-        for (unsigned int i = 0; i < moCoefficients.size(); ++i)
-          coeffs.push_back(static_cast<double>(moCoefficients[i]));
+        for (auto & moCoefficient : moCoefficients)
+          coeffs.push_back(static_cast<double>(moCoefficient));
         basis->setMolecularOrbitals(coeffs);
       } else if (isNumericArray(moCoefficientsA) &&
                  isNumericArray(moCoefficientsB)) {
         std::vector<double> coeffsA;
-        for (unsigned int i = 0; i < moCoefficientsA.size(); ++i)
-          coeffsA.push_back(static_cast<double>(moCoefficientsA[i]));
+        for (auto & i : moCoefficientsA)
+          coeffsA.push_back(static_cast<double>(i));
         std::vector<double> coeffsB;
-        for (unsigned int i = 0; i < moCoefficientsB.size(); ++i)
-          coeffsB.push_back(static_cast<double>(moCoefficientsB[i]));
+        for (auto & i : moCoefficientsB)
+          coeffsB.push_back(static_cast<double>(i));
         basis->setMolecularOrbitals(coeffsA, BasisSet::Alpha);
         basis->setMolecularOrbitals(coeffsB, BasisSet::Beta);
       } else {
@@ -400,17 +416,17 @@ bool CjsonFormat::read(std::istream& file, Molecule& molecule)
           moCoefficientsB = orbSets[idx]["betaCoefficients"];
           if (isNumericArray(moCoefficients)) {
             std::vector<double> coeffs;
-            for (unsigned int i = 0; i < moCoefficients.size(); ++i)
-              coeffs.push_back(static_cast<double>(moCoefficients[i]));
+            for (auto & moCoefficient : moCoefficients)
+              coeffs.push_back(static_cast<double>(moCoefficient));
             basis->setMolecularOrbitals(coeffs, BasisSet::Paired, idx);
           } else if (isNumericArray(moCoefficientsA) &&
                      isNumericArray(moCoefficientsB)) {
             std::vector<double> coeffsA;
-            for (unsigned int i = 0; i < moCoefficientsA.size(); ++i)
-              coeffsA.push_back(static_cast<double>(moCoefficientsA[i]));
+            for (auto & i : moCoefficientsA)
+              coeffsA.push_back(static_cast<double>(i));
             std::vector<double> coeffsB;
-            for (unsigned int i = 0; i < moCoefficientsB.size(); ++i)
-              coeffsB.push_back(static_cast<double>(moCoefficientsB[i]));
+            for (auto & i : moCoefficientsB)
+              coeffsB.push_back(static_cast<double>(i));
             basis->setMolecularOrbitals(coeffsA, BasisSet::Alpha, idx);
             basis->setMolecularOrbitals(coeffsB, BasisSet::Beta, idx);
           }
@@ -428,30 +444,37 @@ bool CjsonFormat::read(std::istream& file, Molecule& molecule)
     json frequencies = vibrations["frequencies"];
     if (isNumericArray(frequencies)) {
       Array<double> freqs;
-      for (unsigned int i = 0; i < frequencies.size(); ++i) {
-        freqs.push_back(static_cast<double>(frequencies[i]));
+      for (auto & frequencie : frequencies) {
+        freqs.push_back(static_cast<double>(frequencie));
       }
       molecule.setVibrationFrequencies(freqs);
     }
     json intensities = vibrations["intensities"];
     if (isNumericArray(intensities)) {
       Array<double> intens;
-      for (unsigned int i = 0; i < intensities.size(); ++i) {
-        intens.push_back(static_cast<double>(intensities[i]));
+      for (auto & intensitie : intensities) {
+        intens.push_back(static_cast<double>(intensitie));
       }
-      molecule.setVibrationIntensities(intens);
+      molecule.setVibrationIRIntensities(intens);
+    }
+    json raman = vibrations["ramanIntensities"];
+    if (isNumericArray(raman)) {
+      Array<double> intens;
+      for (auto & i : raman) {
+        intens.push_back(static_cast<double>(i));
+      }
+      molecule.setVibrationRamanIntensities(intens);
     }
     json displacements = vibrations["eigenVectors"];
     if (displacements.is_array()) {
       Array<Array<Vector3>> disps;
-      for (unsigned int i = 0; i < displacements.size(); ++i) {
-        json arr = displacements[i];
+      for (auto arr : displacements) {
         if (isNumericArray(arr)) {
           Array<Vector3> mode;
           mode.resize(arr.size() / 3);
           double* ptr = &mode[0][0];
-          for (unsigned int j = 0; j < arr.size(); ++j) {
-            *(ptr++) = static_cast<double>(arr[j]);
+          for (auto & j : arr) {
+            *(ptr++) = static_cast<double>(j);
           }
           disps.push_back(mode);
         }
@@ -549,8 +572,8 @@ bool CjsonFormat::write(std::ostream& file, const Molecule& molecule)
     // Map the shell types from enumeration to integer values.
     auto symmetry = gaussian->symmetry();
     json shellTypes;
-    for (size_t i = 0; i < symmetry.size(); ++i) {
-      switch (symmetry[i]) {
+    for (int i : symmetry) {
+      switch (i) {
         case GaussianSet::S:
           shellTypes.push_back(0);
           break;
@@ -582,8 +605,8 @@ bool CjsonFormat::write(std::ostream& file, const Molecule& molecule)
 
       auto atomIndices = gaussian->atomIndices();
       json shellToAtomMap;
-      for (size_t i = 0; i < atomIndices.size(); ++i)
-        shellToAtomMap.push_back(atomIndices[i]);
+      for (unsigned int & atomIndice : atomIndices)
+        shellToAtomMap.push_back(atomIndice);
       basis["shellToAtomMap"] = shellToAtomMap;
 
       auto gtoC = gaussian->gtoC();
@@ -625,24 +648,23 @@ bool CjsonFormat::write(std::ostream& file, const Molecule& molecule)
     auto energies = gaussian->moEnergy();
     if (energies.size() > 0) {
       json energyData;
-      for (auto it = energies.begin(), itEnd = energies.end(); it != itEnd;
-           ++it) {
-        energyData.push_back(*it);
+      for (double & energie : energies) {
+        energyData.push_back(energie);
       }
       root["orbitals"]["energies"] = energyData;
     }
     auto occ = gaussian->moOccupancy();
     if (occ.size() > 0) {
       json occData;
-      for (auto it = occ.begin(), itEnd = occ.end(); it != itEnd; ++it)
-        occData.push_back(static_cast<int>(*it));
+      for (unsigned char & it : occ)
+        occData.push_back(static_cast<int>(it));
       root["orbitals"]["occupations"] = occData;
     }
     auto num = gaussian->moNumber();
     if (num.size() > 0) {
       json numData;
-      for (auto it = num.begin(), itEnd = num.end(); it != itEnd; ++it)
-        numData.push_back(*it);
+      for (unsigned int & it : num)
+        numData.push_back(it);
       root["orbitals"]["numbers"] = numData;
     }
 
@@ -653,10 +675,8 @@ bool CjsonFormat::write(std::ostream& file, const Molecule& molecule)
   if (molecule.cubeCount() > 0) {
     const Cube* cube = molecule.cube(0);
     json cubeData;
-    for (vector<double>::const_iterator it = cube->data()->begin(),
-                                        itEnd = cube->data()->end();
-         it != itEnd; ++it) {
-      cubeData.push_back(*it);
+    for (float it : *cube->data()) {
+      cubeData.push_back(it);
     }
     // Get the origin, max, spacing, and dimensions to place in the object.
     json cubeObj;
@@ -706,13 +726,10 @@ bool CjsonFormat::write(std::ostream& file, const Molecule& molecule)
     if (molecule.atomPositions3d().size() == molecule.atomCount()) {
       // everything gets real-space Cartesians
       json coords3d;
-      for (vector<Vector3>::const_iterator
-             it = molecule.atomPositions3d().begin(),
-             itEnd = molecule.atomPositions3d().end();
-           it != itEnd; ++it) {
-        coords3d.push_back(it->x());
-        coords3d.push_back(it->y());
-        coords3d.push_back(it->z());
+      for (const auto & it : molecule.atomPositions3d()) {
+        coords3d.push_back(it.x());
+        coords3d.push_back(it.y());
+        coords3d.push_back(it.z());
       }
       root["atoms"]["coords"]["3d"] = coords3d;
 
@@ -722,12 +739,10 @@ bool CjsonFormat::write(std::ostream& file, const Molecule& molecule)
         Array<Vector3> fcoords;
         CrystalTools::fractionalCoordinates(
           *molecule.unitCell(), molecule.atomPositions3d(), fcoords);
-        for (vector<Vector3>::const_iterator it = fcoords.begin(),
-                                             itEnd = fcoords.end();
-             it != itEnd; ++it) {
-          coordsFractional.push_back(it->x());
-          coordsFractional.push_back(it->y());
-          coordsFractional.push_back(it->z());
+        for (auto & fcoord : fcoords) {
+          coordsFractional.push_back(fcoord.x());
+          coordsFractional.push_back(fcoord.y());
+          coordsFractional.push_back(fcoord.z());
         }
         root["atoms"]["coords"]["3dFractional"] = coordsFractional;
       }
@@ -736,12 +751,9 @@ bool CjsonFormat::write(std::ostream& file, const Molecule& molecule)
     // 2d positions:
     if (molecule.atomPositions2d().size() == molecule.atomCount()) {
       json coords2d;
-      for (vector<Vector2>::const_iterator
-             it = molecule.atomPositions2d().begin(),
-             itEnd = molecule.atomPositions2d().end();
-           it != itEnd; ++it) {
-        coords2d.push_back(it->x());
-        coords2d.push_back(it->y());
+      for (const auto & it : molecule.atomPositions2d()) {
+        coords2d.push_back(it.x());
+        coords2d.push_back(it.y());
       }
       root["atoms"]["coords"]["2d"] = coords2d;
     }
@@ -754,6 +766,13 @@ bool CjsonFormat::write(std::ostream& file, const Molecule& molecule)
   }
   root["atoms"]["labels"] = labels;
 
+  // formal charges
+  json formalCharges;
+  for (size_t i = 0; i < molecule.atomCount(); ++i) {
+    formalCharges.push_back(molecule.formalCharge(i));
+  }
+  root["atoms"]["formalCharges"] = formalCharges;
+
   auto layer = LayerManager::getMoleculeInfo(&molecule)->layer;
   if (layer.atomCount()) {
     json atomLayer;
@@ -796,7 +815,7 @@ bool CjsonFormat::write(std::ostream& file, const Molecule& molecule)
       entry["color"] = color;
 
       json atoms;
-      for (auto item : residue.atomNameMap()) {
+      for (const auto& item : residue.atomNameMap()) {
         // dictionary between names and atom Id
         atoms[item.first] = item.second.index();
       }
@@ -810,19 +829,20 @@ bool CjsonFormat::write(std::ostream& file, const Molecule& molecule)
   if (molecule.vibrationFrequencies().size() > 0) {
     // A few sanity checks before we begin.
     assert(molecule.vibrationFrequencies().size() ==
-           molecule.vibrationIntensities().size());
+           molecule.vibrationIRIntensities().size());
     json modes;
     json freqs;
     json inten;
+    json raman;
     json eigenVectors;
     for (size_t i = 0; i < molecule.vibrationFrequencies().size(); ++i) {
       modes.push_back(static_cast<unsigned int>(i) + 1);
       freqs.push_back(molecule.vibrationFrequencies()[i]);
-      inten.push_back(molecule.vibrationIntensities()[i]);
+      inten.push_back(molecule.vibrationIRIntensities()[i]);
+      raman.push_back(molecule.vibrationRamanIntensities()[i]);
       Core::Array<Vector3> atomDisplacements = molecule.vibrationLx(i);
       json eigenVector;
-      for (size_t j = 0; j < atomDisplacements.size(); ++j) {
-        Vector3 pos = atomDisplacements[j];
+      for (auto pos : atomDisplacements) {
         eigenVector.push_back(pos[0]);
         eigenVector.push_back(pos[1]);
         eigenVector.push_back(pos[2]);
@@ -832,6 +852,7 @@ bool CjsonFormat::write(std::ostream& file, const Molecule& molecule)
     root["vibrations"]["modes"] = modes;
     root["vibrations"]["frequencies"] = freqs;
     root["vibrations"]["intensities"] = inten;
+    root["vibrations"]["ramanIntensities"] = raman;
     root["vibrations"]["eigenVectors"] = eigenVectors;
   }
 
@@ -871,16 +892,15 @@ bool CjsonFormat::write(std::ostream& file, const Molecule& molecule)
 vector<std::string> CjsonFormat::fileExtensions() const
 {
   vector<std::string> ext;
-  ext.push_back("cjson");
+  ext.emplace_back("cjson");
   return ext;
 }
 
 vector<std::string> CjsonFormat::mimeTypes() const
 {
   vector<std::string> mime;
-  mime.push_back("chemical/x-cjson");
+  mime.emplace_back("chemical/x-cjson");
   return mime;
 }
 
-} // namespace Io
 } // namespace Avogadro
