@@ -1,17 +1,6 @@
 /******************************************************************************
-
   This source file is part of the Avogadro project.
-
-  Copyright 2013 Kitware, Inc.
-
-  This source code is released under the New BSD License, (the "License").
-
-  Unless required by applicable law or agreed to in writing, software
-  distributed under the License is distributed on an "AS IS" BASIS,
-  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-  See the License for the specific language governing permissions and
-  limitations under the License.
-
+  This source code is released under the 3-Clause BSD License, (see "LICENSE").
 ******************************************************************************/
 
 #include "gromacsformat.h"
@@ -31,8 +20,7 @@
 #include <string>
 #include <utility>
 
-namespace Avogadro {
-namespace Io {
+namespace Avogadro::Io {
 
 using Core::Atom;
 using Core::Elements;
@@ -78,7 +66,7 @@ bool GromacsFormat::read(std::istream& in, Molecule& molecule)
   getline(in, buffer);
   buffer = trimmed(buffer);
   bool ok;
-  size_t numAtoms = lexicalCast<size_t>(buffer, ok);
+  auto numAtoms = lexicalCast<size_t>(buffer, ok);
   if (buffer.empty() || !ok) {
     appendError("Number of atoms (line 2) invalid.");
     return false;
@@ -126,7 +114,7 @@ bool GromacsFormat::read(std::istream& in, Molecule& molecule)
     // Offset: 52 format: %8.4f value: y velocity (nm/ps, a.k.a. km/s)
     // Offset: 60 format: %8.4f value: z velocity (nm/ps, a.k.a. km/s)
 
-    size_t residueId = lexicalCast<size_t>(buffer.substr(0, 5), ok);
+    auto residueId = lexicalCast<size_t>(buffer.substr(0, 5), ok);
     if (!ok) {
       appendError("Failed to parse residue sequence number: " +
                   buffer.substr(0, 5));
@@ -136,7 +124,7 @@ bool GromacsFormat::read(std::istream& in, Molecule& molecule)
     if (residueId != currentResidueId) {
       currentResidueId = residueId;
 
-      string residueName = lexicalCast<string>(buffer.substr(5, 5), ok);
+      auto residueName = lexicalCast<string>(buffer.substr(5, 5), ok);
       if (!ok) {
         appendError("Failed to parse residue name: " + buffer.substr(5, 5));
         return false;
@@ -159,7 +147,7 @@ bool GromacsFormat::read(std::istream& in, Molecule& molecule)
       if (atomicNumFromSymbol != 255) {
         atom = molecule.addAtom(atomicNumFromSymbol);
       } else {
-        AtomTypeMap::const_iterator it = atomTypes.find(value);
+        auto it = atomTypes.find(value);
         if (it == atomTypes.end()) {
           atomTypes.insert(std::make_pair(value, customElementCounter++));
           it = atomTypes.find(value);
@@ -192,10 +180,8 @@ bool GromacsFormat::read(std::istream& in, Molecule& molecule)
   // Set the custom element map if needed:
   if (!atomTypes.empty()) {
     Molecule::CustomElementMap elementMap;
-    for (AtomTypeMap::const_iterator it = atomTypes.begin(),
-                                     itEnd = atomTypes.end();
-         it != itEnd; ++it) {
-      elementMap.insert(std::make_pair(it->second, it->first));
+    for (const auto & atomType : atomTypes) {
+      elementMap.insert(std::make_pair(atomType.second, atomType.first));
     }
     molecule.setCustomElementMap(elementMap);
   }
@@ -227,7 +213,7 @@ bool GromacsFormat::read(std::istream& in, Molecule& molecule)
       }
     }
 
-    UnitCell* cell = new UnitCell;
+    auto* cell = new UnitCell;
     cell->setCellMatrix(cellMatrix * static_cast<Real>(10)); // nm --> Angstrom
     molecule.setUnitCell(cell);
   }
@@ -240,5 +226,4 @@ bool GromacsFormat::write(std::ostream&, const Core::Molecule&)
   return false;
 }
 
-} // namespace Io
 } // namespace Avogadro
