@@ -19,8 +19,7 @@
 #include <QtCore/QJsonArray>
 #include <QtCore/QJsonDocument>
 
-namespace Avogadro {
-namespace MoleQueue {
+namespace Avogadro::MoleQueue {
 
 using QtGui::PythonScript;
 using QtGui::GenericHighlighter;
@@ -214,7 +213,7 @@ bool InputGenerator::generateInput(const QJsonObject& options_,
 
               // Concatenate the requested styles for this input file.
               if (fileObj["highlightStyles"].isArray()) {
-                GenericHighlighter* highlighter(new GenericHighlighter(this));
+                auto* highlighter(new GenericHighlighter(this));
                 foreach (const QJsonValue& styleVal,
                          fileObj["highlightStyles"].toArray()) {
                   if (styleVal.isString()) {
@@ -348,7 +347,7 @@ bool InputGenerator::insertMolecule(QJsonObject& json,
     formats.newFormatFromFileExtension(m_moleculeExtension.toStdString()));
 
   if (format.isNull()) {
-    m_errors << tr("Error writing molecule representation to string: "
+    m_errors << tr("Error saving molecule representation to string: "
                    "Unrecognized file format: %1")
                   .arg(m_moleculeExtension);
     return false;
@@ -356,7 +355,7 @@ bool InputGenerator::insertMolecule(QJsonObject& json,
 
   std::string str;
   if (!format->writeString(str, mol)) {
-    m_errors << tr("Error writing molecule representation to string: %1")
+    m_errors << tr("Error saving molecule representation to string: %1", "%1 = error message")
                   .arg(QString::fromStdString(format->error()));
     return false;
   }
@@ -410,7 +409,7 @@ void InputGenerator::replaceKeywords(QString& str,
 
   // Find each coordinate block keyword in the file, then generate and replace
   // it with the appropriate values.
-  QRegExp coordParser("\\$\\$coords:([^\\$]*)\\$\\$");
+  QRegExp coordParser(R"(\$\$coords:([^\$]*)\$\$)");
   int ind = 0;
   while ((ind = coordParser.indexIn(str, ind)) != -1) {
     // Extract spec and prepare the replacement
@@ -465,10 +464,10 @@ bool InputGenerator::parseHighlightStyles(const QJsonArray& json) const
     }
     QJsonArray rulesArray(styleObj.value("rules").toArray());
 
-    GenericHighlighter* highlighter(
+    auto* highlighter(
       new GenericHighlighter(const_cast<InputGenerator*>(this)));
     if (!parseRules(rulesArray, *highlighter)) {
-      qDebug() << "Error parsing style" << styleName << endl
+      qDebug() << "Error parsing style" << styleName << '\n'
                << QString(QJsonDocument(styleObj).toJson());
       highlighter->deleteLater();
       result = false;
@@ -493,13 +492,13 @@ bool InputGenerator::parseRules(const QJsonArray& json,
     QJsonObject ruleObj(ruleVal.toObject());
 
     if (!ruleObj.contains("patterns")) {
-      qDebug() << "Rule missing 'patterns' array:" << endl
+      qDebug() << "Rule missing 'patterns' array:" << '\n'
                << QString(QJsonDocument(ruleObj).toJson());
       result = false;
       continue;
     }
     if (!ruleObj.value("patterns").isArray()) {
-      qDebug() << "Rule 'patterns' member is not an array:" << endl
+      qDebug() << "Rule 'patterns' member is not an array:" << '\n'
                << QString(QJsonDocument(ruleObj).toJson());
       result = false;
       continue;
@@ -507,13 +506,13 @@ bool InputGenerator::parseRules(const QJsonArray& json,
     QJsonArray patternsArray(ruleObj.value("patterns").toArray());
 
     if (!ruleObj.contains("format")) {
-      qDebug() << "Rule missing 'format' object:" << endl
+      qDebug() << "Rule missing 'format' object:" << '\n'
                << QString(QJsonDocument(ruleObj).toJson());
       result = false;
       continue;
     }
     if (!ruleObj.value("format").isObject()) {
-      qDebug() << "Rule 'format' member is not an object:" << endl
+      qDebug() << "Rule 'format' member is not an object:" << '\n'
                << QString(QJsonDocument(ruleObj).toJson());
       result = false;
       continue;
@@ -525,7 +524,7 @@ bool InputGenerator::parseRules(const QJsonArray& json,
     foreach (QJsonValue patternVal, patternsArray) {
       QRegExp pattern;
       if (!parsePattern(patternVal, pattern)) {
-        qDebug() << "Error while parsing pattern:" << endl
+        qDebug() << "Error while parsing pattern:" << '\n'
                  << QString(QJsonDocument(patternVal.toObject()).toJson());
         result = false;
         continue;
@@ -535,7 +534,7 @@ bool InputGenerator::parseRules(const QJsonArray& json,
 
     QTextCharFormat format;
     if (!parseFormat(formatObj, format)) {
-      qDebug() << "Error while parsing format:" << endl
+      qDebug() << "Error while parsing format:" << '\n'
                << QString(QJsonDocument(formatObj).toJson());
       result = false;
     }
@@ -676,5 +675,4 @@ bool InputGenerator::parsePattern(const QJsonValue& json,
   return true;
 }
 
-} // namespace MoleQueue
 } // namespace Avogadro
