@@ -6,14 +6,15 @@
 #include "pythonscript.h"
 
 #include "avogadropython.h"
+#include "utilities.h"
 
 #include <QtCore/QDebug>
+#include <QtCore/QFileInfo>
 #include <QtCore/QLocale>
 #include <QtCore/QProcess>
 #include <QtCore/QSettings>
 
-namespace Avogadro {
-namespace QtGui {
+namespace Avogadro::QtGui {
 
 PythonScript::PythonScript(const QString& scriptFilePath_, QObject* parent_)
   : QObject(parent_), m_debug(!qgetenv("AVO_PYTHON_SCRIPT_DEBUG").isEmpty()),
@@ -38,13 +39,37 @@ void PythonScript::setScriptFilePath(const QString& scriptFile)
 
 void PythonScript::setDefaultPythonInterpretor()
 {
-  m_pythonInterpreter = qgetenv("AVO_PYTHON_INTERPRETER");
   if (m_pythonInterpreter.isEmpty()) {
     m_pythonInterpreter =
       QSettings().value(QStringLiteral("interpreters/python")).toString();
   }
   if (m_pythonInterpreter.isEmpty())
+    // compiled-in default
     m_pythonInterpreter = pythonInterpreterPath;
+
+  // check to see if the interpreter exists and is executable
+  QFileInfo info(m_pythonInterpreter);
+  if (!info.isExecutable()) {
+    qWarning() << "Python interpreter" << m_pythonInterpreter
+               << "does not exist trying \"python\" in your path."
+               << "Please set a path to the python interpreter.";
+
+    // let's try to find a python
+#ifdef Q_OS_WIN
+    QString python("python.exe");
+#else
+    QString python("python3");
+#endif
+
+    QString path = Utilities::findExecutablePath(python);
+    if (path.isEmpty()) {
+      qWarning() << "Can't find python in your path";
+    } else {
+      // add a "/" to the end
+      path.append('/');
+    }
+    m_pythonInterpreter = path + python;
+  }
 }
 
 QByteArray PythonScript::execute(const QStringList& args,
@@ -63,7 +88,7 @@ QByteArray PythonScript::execute(const QStringList& args,
 
   // Add the global language / locale to *all* calls
   realArgs.append("--lang");
-  realArgs.append(QLocale::system().name());
+  realArgs.append(QLocale().name());
 
   // Start script
   realArgs.prepend(m_scriptFilePath);
@@ -148,7 +173,7 @@ void PythonScript::asyncExecute(const QStringList& args,
 
   // Add the global language / locale to *all* calls
   realArgs.append("--lang");
-  realArgs.append(QLocale::system().name());
+  realArgs.append(QLocale().name());
 
   // Start script
   realArgs.prepend(m_scriptFilePath);
@@ -230,5 +255,4 @@ QString PythonScript::processErrorString(const QProcess& proc) const
   return result;
 }
 
-} // namespace QtGui
 } // namespace Avogadro
