@@ -1,17 +1,6 @@
 /******************************************************************************
-
   This source file is part of the Avogadro project.
-
-  Copyright 2013-2015 Kitware, Inc.
-
-  This source code is released under the New BSD License, (the "License").
-
-  Unless required by applicable law or agreed to in writing, software
-  distributed under the License is distributed on an "AS IS" BASIS,
-  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-  See the License for the specific language governing permissions and
-  limitations under the License.
-
+  This source code is released under the 3-Clause BSD License, (see "LICENSE").
 ******************************************************************************/
 
 #include "rwmolecule.h"
@@ -26,8 +15,7 @@
 #include <avogadro/core/spacegroups.h>
 #include <avogadro/qtgui/hydrogentools.h>
 
-namespace Avogadro {
-namespace QtGui {
+namespace Avogadro::QtGui {
 
 using Core::Array;
 using Core::AtomHybridization;
@@ -35,17 +23,17 @@ using Core::CrystalTools;
 using Core::UnitCell;
 using std::swap;
 
-RWMolecule::RWMolecule(Molecule& mol, QObject* p) : QObject(p), m_molecule(mol)
+RWMolecule::RWMolecule(Molecule& mol, QObject* p) : QObject(p), m_molecule(mol), m_interactive(false)
 {}
 
 RWMolecule::~RWMolecule() {}
 
 RWMolecule::AtomType RWMolecule::addAtom(unsigned char num, bool usingPositions)
 {
-  Index atomId = static_cast<Index>(m_molecule.atomCount());
-  Index atomUid = static_cast<Index>(m_molecule.m_atomUniqueIds.size());
+  auto atomId = static_cast<Index>(m_molecule.atomCount());
+  auto atomUid = static_cast<Index>(m_molecule.m_atomUniqueIds.size());
 
-  AddAtomCommand* comm =
+  auto* comm =
     new AddAtomCommand(*this, num, usingPositions, atomId, atomUid);
   comm->setText(tr("Add Atom"));
   m_undoStack.push(comm);
@@ -91,7 +79,7 @@ bool RWMolecule::removeAtom(Index atomId)
     atomBonds.pop_back();
   }
 
-  RemoveAtomCommand* comm = new RemoveAtomCommand(
+  auto* comm = new RemoveAtomCommand(
     *this, atomId, uniqueId, atomicNumber(atomId), atomPosition3d(atomId));
   comm->setText(tr("Remove Atom"));
 
@@ -124,8 +112,8 @@ void RWMolecule::adjustHydrogens(Index atomId)
 void RWMolecule::adjustHydrogens(const Core::Array<Index>& atomIds)
 {
   m_undoStack.beginMacro(tr("Adjust Hydrogens"));
-  for (Index i = 0; i < atomIds.size(); ++i) {
-    adjustHydrogens(atomIds[i]);
+  for (unsigned long atomId : atomIds) {
+    adjustHydrogens(atomId);
   }
   m_undoStack.endMacro();
 }
@@ -135,7 +123,7 @@ bool RWMolecule::setAtomicNumbers(const Core::Array<unsigned char>& nums)
   if (nums.size() != m_molecule.atomCount())
     return false;
 
-  SetAtomicNumbersCommand* comm =
+  auto* comm =
     new SetAtomicNumbersCommand(*this, m_molecule.atomicNumbers(), nums);
   comm->setText(tr("Change Elements"));
   m_undoStack.push(comm);
@@ -147,7 +135,7 @@ bool RWMolecule::setAtomicNumber(Index atomId, unsigned char num)
   if (atomId >= atomCount())
     return false;
 
-  SetAtomicNumberCommand* comm = new SetAtomicNumberCommand(
+  auto* comm = new SetAtomicNumberCommand(
     *this, atomId, m_molecule.atomicNumber(atomId), num);
   comm->setText(tr("Change Element"));
   m_undoStack.push(comm);
@@ -160,7 +148,7 @@ bool RWMolecule::setAtomPositions3d(const Core::Array<Vector3>& pos,
   if (pos.size() != m_molecule.atomCount())
     return false;
 
-  SetPositions3dCommand* comm =
+  auto* comm =
     new SetPositions3dCommand(*this, m_molecule.m_positions3d, pos);
   comm->setText(undoText);
   comm->setCanMerge(m_interactive);
@@ -171,7 +159,7 @@ bool RWMolecule::setAtomPositions3d(const Core::Array<Vector3>& pos,
 bool RWMolecule::setLabel(Index atomId, const std::string& label,
                           const QString& undoText)
 {
-  ModifyLabelCommand* comm = new ModifyLabelCommand(*this, atomId, label);
+  auto* comm = new ModifyLabelCommand(*this, atomId, label);
   comm->setText(undoText);
   m_undoStack.push(comm);
   return true;
@@ -186,7 +174,7 @@ bool RWMolecule::setAtomPosition3d(Index atomId, const Vector3& pos,
   if (m_molecule.m_positions3d.size() != m_molecule.atomCount())
     m_molecule.m_positions3d.resize(m_molecule.atomCount(), Vector3::Zero());
 
-  SetPosition3dCommand* comm = new SetPosition3dCommand(
+  auto* comm = new SetPosition3dCommand(
     *this, atomId, m_molecule.m_positions3d[atomId], pos);
   comm->setText(undoText);
   comm->setCanMerge(m_interactive);
@@ -210,7 +198,7 @@ bool RWMolecule::setHybridization(Index atomId, Core::AtomHybridization hyb)
   if (atomId >= atomCount())
     return false;
 
-  SetAtomicNumberCommand* comm = new SetAtomicNumberCommand(
+  auto* comm = new SetAtomicNumberCommand(
     *this, atomId, m_molecule.hybridization(atomId), hyb);
   comm->setText(tr("Change Atom Hybridization"));
   m_undoStack.push(comm);
@@ -222,7 +210,7 @@ bool RWMolecule::setFormalCharge(Index atomId, signed char charge)
   if (atomId >= atomCount())
     return false;
 
-  SetAtomFormalChargeCommand* comm = new SetAtomFormalChargeCommand(
+  auto* comm = new SetAtomFormalChargeCommand(
     *this, atomId, m_molecule.formalCharge(atomId), charge);
   comm->setText(tr("Change Atom Formal Charge"));
   m_undoStack.push(comm);
@@ -234,7 +222,7 @@ bool RWMolecule::setColor(Index atomId, Vector3ub color)
   if (atomId >= atomCount())
     return false;
 
-  SetAtomColorCommand* comm =
+  auto* comm =
     new SetAtomColorCommand(*this, atomId, m_molecule.color(atomId), color);
   comm->setText(tr("Change Atom Color"));
   m_undoStack.push(comm);
@@ -246,7 +234,7 @@ bool RWMolecule::setLayer(Index atomId, size_t layer)
   if (atomId >= atomCount())
     return false;
 
-  SetLayerCommand* comm =
+  auto* comm =
     new SetLayerCommand(*this, atomId, m_molecule.layer(atomId), layer);
   comm->setText(tr("Change Atom Layer"));
   m_undoStack.push(comm);
@@ -260,9 +248,9 @@ RWMolecule::BondType RWMolecule::addBond(Index atom1, Index atom2,
     return BondType();
 
   Index bondId = bondCount();
-  Index bondUid = static_cast<Index>(m_molecule.m_bondUniqueIds.size());
+  auto bondUid = static_cast<Index>(m_molecule.m_bondUniqueIds.size());
 
-  AddBondCommand* comm = new AddBondCommand(
+  auto* comm = new AddBondCommand(
     *this, order, Molecule::makeBondPair(atom1, atom2), bondId, bondUid);
   comm->setText(tr("Add Bond"));
   m_undoStack.push(comm);
@@ -287,7 +275,7 @@ bool RWMolecule::removeBond(Index bondId)
   if (bondUid == MaxIndex)
     return false;
 
-  RemoveBondCommand* comm =
+  auto* comm =
     new RemoveBondCommand(*this, bondId, bondUid, m_molecule.bondPair(bondId),
                           m_molecule.bondOrder(bondId));
   comm->setText(tr("Removed Bond"));
@@ -310,7 +298,7 @@ bool RWMolecule::setBondOrders(const Core::Array<unsigned char>& orders)
   if (orders.size() != m_molecule.bondCount())
     return false;
 
-  SetBondOrdersCommand* comm =
+  auto* comm =
     new SetBondOrdersCommand(*this, m_molecule.bondOrders(), orders);
   comm->setText(tr("Set Bond Orders"));
   m_undoStack.push(comm);
@@ -322,7 +310,7 @@ bool RWMolecule::setBondOrder(Index bondId, unsigned char order)
   if (bondId >= bondCount())
     return false;
 
-  SetBondOrderCommand* comm =
+  auto* comm =
     new SetBondOrderCommand(*this, bondId, m_molecule.bondOrder(bondId), order);
   comm->setText(tr("Change Bond Order"));
   // Always allow merging, but only if bondId is the same.
@@ -345,7 +333,7 @@ bool RWMolecule::setBondPairs(const Array<std::pair<Index, Index>>& pairs)
     if (p_const[i].first > p_const[i].second)
       swap(p[i].first, p[i].second);
 
-  SetBondPairsCommand* comm =
+  auto* comm =
     new SetBondPairsCommand(*this, m_molecule.bondPairs(), p);
   comm->setText(tr("Update Bonds"));
   m_undoStack.push(comm);
@@ -377,14 +365,14 @@ void RWMolecule::addUnitCell()
   if (m_molecule.unitCell())
     return;
 
-  UnitCell* cell = new UnitCell;
+  auto* cell = new UnitCell;
   cell->setCellParameters(
     static_cast<Real>(3.0), static_cast<Real>(3.0), static_cast<Real>(3.0),
     static_cast<Real>(90.0) * DEG_TO_RAD, static_cast<Real>(90.0) * DEG_TO_RAD,
     static_cast<Real>(90.0) * DEG_TO_RAD);
   m_molecule.setUnitCell(cell);
 
-  AddUnitCellCommand* comm =
+  auto* comm =
     new AddUnitCellCommand(*this, *m_molecule.unitCell());
   comm->setText(tr("Add Unit Cell"));
   m_undoStack.push(comm);
@@ -397,7 +385,7 @@ void RWMolecule::removeUnitCell()
   if (!m_molecule.unitCell())
     return;
 
-  RemoveUnitCellCommand* comm =
+  auto* comm =
     new RemoveUnitCellCommand(*this, *m_molecule.unitCell());
   comm->setText(tr("Remove Unit Cell"));
   m_undoStack.push(comm);
@@ -410,7 +398,7 @@ void RWMolecule::modifyMolecule(const Molecule& newMolecule,
                                 Molecule::MoleculeChanges changes,
                                 const QString& undoText)
 {
-  ModifyMoleculeCommand* comm =
+  auto* comm =
     new ModifyMoleculeCommand(*this, m_molecule, newMolecule);
 
   comm->setText(undoText);
@@ -431,7 +419,9 @@ void RWMolecule::appendMolecule(const Molecule& mol, const QString& undoText)
   Index offset = atomCount();
   for (size_t i = 0; i < mol.atomCount(); ++i) {
     Core::Atom atom = mol.atom(i);
-    addAtom(atom.atomicNumber(), atom.position3d());
+    AtomType new_atom = addAtom(atom.atomicNumber(), atom.position3d());
+    new_atom.setFormalCharge(atom.formalCharge());
+
     setAtomSelected(atomCount() - 1, true);
   }
   // now loop through and add the bonds
@@ -477,7 +467,7 @@ void RWMolecule::wrapAtomsToCell()
   CrystalTools::wrapAtomsToUnitCell(m_molecule);
   Core::Array<Vector3> newPos = m_molecule.atomPositions3d();
 
-  SetPositions3dCommand* comm =
+  auto* comm =
     new SetPositions3dCommand(*this, oldPos, newPos);
   comm->setText(tr("Wrap Atoms to Cell"));
   m_undoStack.push(comm);
@@ -712,7 +702,7 @@ bool RWMolecule::setForceVector(Index atomId, const Vector3& forces,
   if (m_molecule.m_positions3d.size() != m_molecule.atomCount())
     m_molecule.m_positions3d.resize(m_molecule.atomCount(), Vector3::Zero());
 
-  SetForceVectorCommand* comm = new SetForceVectorCommand(
+  auto* comm = new SetForceVectorCommand(
     *this, atomId, m_molecule.m_positions3d[atomId], forces);
   comm->setText(undoText);
   comm->setCanMerge(m_interactive);
@@ -720,5 +710,4 @@ bool RWMolecule::setForceVector(Index atomId, const Vector3& forces,
   return true;
 }
 
-} // namespace QtGui
 } // namespace Avogadro
