@@ -1,17 +1,6 @@
 /******************************************************************************
-
   This source file is part of the Avogadro project.
-
-  Copyright 2013 Kitware, Inc.
-
-  This source code is released under the New BSD License, (the "License").
-
-  Unless required by applicable law or agreed to in writing, software
-  distributed under the License is distributed on an "AS IS" BASIS,
-  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-  See the License for the specific language governing permissions and
-  limitations under the License.
-
+  This source code is released under the 3-Clause BSD License, (see "LICENSE").
 ******************************************************************************/
 
 #ifndef AVOGADRO_QTGUI_UTILITIES_H
@@ -19,7 +8,7 @@
 
 #include "avogadroqtguiexport.h"
 
-#include <QtCore/QStringList>
+#include <QtCore/QString>
 
 namespace Avogadro {
 namespace QtGui {
@@ -27,6 +16,8 @@ namespace Utilities {
 
 AVOGADROQTGUI_EXPORT QString libraryDirectory();
 AVOGADROQTGUI_EXPORT QString dataDirectory();
+//! \return a fully-qualified path for a program or an empty string if not found
+AVOGADROQTGUI_EXPORT QString findExecutablePath(QString program);
 
 } // namespace Utilities
 } // namespace QtGui
