@@ -1,17 +1,6 @@
 /******************************************************************************
-
   This source file is part of the Avogadro project.
-
-  Copyright 2013 Kitware, Inc.
-
-  This source code is released under the New BSD License, (the "License").
-
-  Unless required by applicable law or agreed to in writing, software
-  distributed under the License is distributed on an "AS IS" BASIS,
-  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-  See the License for the specific language governing permissions and
-  limitations under the License.
-
+  This source code is released under the 3-Clause BSD License, (see "LICENSE").
 ******************************************************************************/
 
 #include <iostream>
@@ -30,8 +19,7 @@
 #include <avogadro/qtgui/meshgenerator.h>
 #include <avogadro/qtgui/molecule.h>
 
-namespace Avogadro {
-namespace QtPlugins {
+namespace Avogadro::QtPlugins {
 
 ApbsOutputDialog::ApbsOutputDialog(QWidget* parent_)
   : QDialog(parent_), m_ui(new Ui::ApbsOutputDialog)
@@ -53,4 +41,3 @@ bool ApbsOutputDialog::loadCubeFile() const
   return m_ui->loadCubeCheckBox->isChecked();
 }
 }
-}
