@@ -1,17 +1,6 @@
 /******************************************************************************
-
   This source file is part of the Avogadro project.
-
-  Copyright 2013 Kitware, Inc.
-
-  This source code is released under the New BSD License, (the "License").
-
-  Unless required by applicable law or agreed to in writing, software
-  distributed under the License is distributed on an "AS IS" BASIS,
-  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-  See the License for the specific language governing permissions and
-  limitations under the License.
-
+  This source code is released under the 3-Clause BSD License, (see "LICENSE").
 ******************************************************************************/
 
 #include "coordinateeditor.h"
@@ -20,13 +9,12 @@
 
 #include <QtWidgets/QAction>
 
-namespace Avogadro {
-namespace QtPlugins {
+namespace Avogadro::QtPlugins {
 
 CoordinateEditor::CoordinateEditor(QObject* parent_)
   : Avogadro::QtGui::ExtensionPlugin(parent_), m_dialog(nullptr),
     m_molecule(nullptr),
-    m_action(new QAction(tr("Atomic &Coordinate Editor..."), this))
+    m_action(new QAction(tr("Atomic &Coordinate Editor…"), this))
 {
   connect(m_action, SIGNAL(triggered()), SLOT(triggered()));
 }
@@ -70,5 +58,4 @@ void CoordinateEditor::pastedMolecule()
   requestActiveTool("Navigator");
 }
 
-} // namespace QtPlugins
 } // namespace Avogadro
