@@ -1,17 +1,6 @@
 /******************************************************************************
-
   This source file is part of the Avogadro project.
-
-  Copyright 2012 Kitware, Inc.
-
-  This source code is released under the New BSD License, (the "License").
-
-  Unless required by applicable law or agreed to in writing, software
-  distributed under the License is distributed on an "AS IS" BASIS,
-  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-  See the License for the specific language governing permissions and
-  limitations under the License.
-
+  This source code is released under the 3-Clause BSD License, (see "LICENSE").
 ******************************************************************************/
 
 #include "cp2kinputdialog.h"
@@ -46,8 +35,7 @@ using Avogadro::MoleQueue::MoleQueueDialog;
 using Avogadro::MoleQueue::MoleQueueManager;
 using Avogadro::MoleQueue::JobObject;
 
-namespace Avogadro {
-namespace QtPlugins {
+namespace Avogadro::QtPlugins {
 
 enum CalculateOption
 {
@@ -560,18 +548,18 @@ void Cp2kInputDialog::updatePreviewText()
   if (title.isEmpty())
     title = generateJobTitle();
 
-  CalculateOption calculate(
+  auto calculate(
     static_cast<CalculateOption>(ui.calculateCombo->currentIndex()));
-  FunctionalOption functional(
+  auto functional(
     static_cast<FunctionalOption>(ui.functionalCombo->currentIndex()));
-  BasisOption basis(static_cast<BasisOption>(ui.basisCombo->currentIndex()));
-  MethodOption method(
+  auto basis(static_cast<BasisOption>(ui.basisCombo->currentIndex()));
+  auto method(
     static_cast<MethodOption>(ui.methodCombo->currentIndex()));
-  EWALDTypeOption EWALDType(
+  auto EWALDType(
     static_cast<EWALDTypeOption>(ui.ewaldtypeCombo->currentIndex()));
-  SCFGuessOption SCFGuess(
+  auto SCFGuess(
     static_cast<SCFGuessOption>(ui.scfguessComboBox->currentIndex()));
-  OTMinimizerOption OTMinimizer(
+  auto OTMinimizer(
     static_cast<OTMinimizerOption>(ui.otminimizerComboBox->currentIndex()));
 
   QString emaxSpline = QString::number(ui.emaxSplineSpin->value());
@@ -776,8 +764,8 @@ void Cp2kInputDialog::updatePreviewText()
 
     for (size_t i = 0; i < m_molecule->atomCount(); ++i) {
       Core::Atom atom = m_molecule->atom(i);
-      for (int i = 0; i < atomList.size(); i++) {
-        if (atomList.at(i) == atom.atomicNumber()) {
+      for (int i : atomList) {
+        if (i == atom.atomicNumber()) {
           inlist = false;
           break;
         } else {
@@ -1041,5 +1029,4 @@ void Cp2kInputDialog::updateTitlePlaceholder()
   ui.titleEdit->setPlaceholderText(generateJobTitle());
 }
 
-} // end namespace QtPlugins
 } // end namespace Avogadro
