@@ -6,9 +6,9 @@
 #include "crystalscene.h"
 
 #include <avogadro/core/array.h>
-#include <avogadro/core/molecule.h>
 #include <avogadro/core/unitcell.h>
 #include <avogadro/qtgui/colorbutton.h>
+#include <avogadro/qtgui/molecule.h>
 #include <avogadro/rendering/geometrynode.h>
 #include <avogadro/rendering/groupnode.h>
 #include <avogadro/rendering/linestripgeometry.h>
@@ -18,23 +18,25 @@
 #include <QtWidgets/QFormLayout>
 #include <QtWidgets/QVBoxLayout>
 
-namespace Avogadro {
-namespace QtPlugins {
+#include <QDebug>
+
+namespace Avogadro::QtPlugins {
 
 using Core::Array;
-using Core::Molecule;
 using Core::UnitCell;
 using Rendering::GeometryNode;
 using Rendering::GroupNode;
 using Rendering::LineStripGeometry;
 
 CrystalScene::CrystalScene(QObject* p)
-  : ScenePlugin(p), m_enabled(true), m_setupWidget(nullptr)
+  : ScenePlugin(p), m_setupWidget(nullptr)
 {
+  m_layerManager = QtGui::PluginLayerManager(m_name);
+
   QSettings settings;
   m_lineWidth = settings.value("crystal/lineWidth", 2.0).toDouble();
 
-  QColor color =
+  auto color =
     settings.value("crystal/color", QColor(Qt::white)).value<QColor>();
   m_color[0] = static_cast<unsigned char>(color.red());
   m_color[1] = static_cast<unsigned char>(color.green());
@@ -43,12 +45,12 @@ CrystalScene::CrystalScene(QObject* p)
 
 CrystalScene::~CrystalScene() {}
 
-void CrystalScene::process(const Molecule& molecule, GroupNode& node)
+void CrystalScene::process(const QtGui::Molecule& molecule, GroupNode& node)
 {
   if (const UnitCell* cell = molecule.unitCell()) {
-    GeometryNode* geometry = new GeometryNode;
+    auto* geometry = new GeometryNode;
     node.addChild(geometry);
-    LineStripGeometry* lines = new LineStripGeometry;
+    auto* lines = new LineStripGeometry;
     geometry->addDrawable(lines);
 
     lines->setColor(m_color);
@@ -69,9 +71,8 @@ void CrystalScene::process(const Molecule& molecule, GroupNode& node)
     strip.push_back(vertex -= b);
     lines->addLineStrip(strip, width);
 
-    for (Array<Vector3f>::iterator it = strip.begin(), itEnd = strip.end();
-         it != itEnd; ++it) {
-      *it += c;
+    for (auto & it : strip) {
+      it += c;
     }
     lines->addLineStrip(strip, width);
 
@@ -94,21 +95,6 @@ void CrystalScene::process(const Molecule& molecule, GroupNode& node)
   }
 }
 
-bool CrystalScene::isEnabled() const
-{
-  return m_enabled;
-}
-
-bool CrystalScene::isActiveLayerEnabled() const
-{
-  return m_enabled;
-}
-
-void CrystalScene::setEnabled(bool enable)
-{
-  m_enabled = enable;
-}
-
 void CrystalScene::setLineWidth(double width)
 {
   m_lineWidth = width;
@@ -134,19 +120,19 @@ QWidget* CrystalScene::setupWidget()
 {
   if (!m_setupWidget) {
     m_setupWidget = new QWidget(qobject_cast<QWidget*>(parent()));
-    QVBoxLayout* v = new QVBoxLayout;
+    auto* v = new QVBoxLayout;
 
     // line width
-    QDoubleSpinBox* spin = new QDoubleSpinBox;
+    auto* spin = new QDoubleSpinBox;
     spin->setRange(0.5, 5.0);
     spin->setSingleStep(0.25);
     spin->setDecimals(2);
     spin->setValue(m_lineWidth);
     connect(spin, SIGNAL(valueChanged(double)), SLOT(setLineWidth(double)));
-    QFormLayout* form = new QFormLayout;
+    auto* form = new QFormLayout;
     form->addRow(tr("Line width:"), spin);
 
-    QtGui::ColorButton* color = new QtGui::ColorButton;
+    auto* color = new QtGui::ColorButton;
     connect(color, SIGNAL(colorChanged(const QColor&)),
             SLOT(setColor(const QColor&)));
     form->addRow(tr("Line color:"), color);
@@ -159,5 +145,4 @@ QWidget* CrystalScene::setupWidget()
   return m_setupWidget;
 }
 
-} // namespace QtPlugins
 } // namespace Avogadro
