@@ -1,22 +1,12 @@
 /******************************************************************************
-
   This source file is part of the Avogadro project.
-
-  Copyright 2013 Kitware, Inc.
-
-  This source code is released under the New BSD License, (the "License").
-
-  Unless required by applicable law or agreed to in writing, software
-  distributed under the License is distributed on an "AS IS" BASIS,
-  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-  See the License for the specific language governing permissions and
-  limitations under the License.
-
+  This source code is released under the 3-Clause BSD License, (see "LICENSE").
 ******************************************************************************/
 
 #ifndef AVOGADRO_QTPLUGINS_MESHES_H
 #define AVOGADRO_QTPLUGINS_MESHES_H
 
+#include <avogadro/core/vector.h>
 #include <avogadro/qtgui/sceneplugin.h>
 
 namespace Avogadro {
@@ -34,21 +24,31 @@ public:
   explicit Meshes(QObject* parent = nullptr);
   ~Meshes() override;
 
-  void process(const Core::Molecule& molecule,
-               Rendering::GroupNode& node) override;
+  void process(const QtGui::Molecule& mol, Rendering::GroupNode& node) override;
 
   QString name() const override { return tr("Meshes"); }
 
-  QString description() const override { return tr("Render triangle meshes."); }
+  QString description() const override { return tr("Render polygon meshes."); }
 
-  bool isEnabled() const override;
+  QWidget* setupWidget() override;
 
-  bool isActiveLayerEnabled() const override;
+  DefaultBehavior defaultBehavior() const override
+  {
+    return DefaultBehavior::False;
+  }
 
-  void setEnabled(bool enable) override;
+private slots:
+  void setColor1(const QColor& color);
+  void setColor2(const QColor& color);
+  void setOpacity(int opacity);
 
 private:
-  bool m_enabled;
+  std::string m_name = "Meshes";
+
+  QWidget* m_setupWidget;
+  unsigned char m_opacity;
+  Vector3ub m_color1;
+  Vector3ub m_color2;
 };
 
 } // end namespace QtPlugins
