@@ -1,17 +1,6 @@
 /******************************************************************************
-
   This source file is part of the Avogadro project.
-
-  Copyright 2012 Kitware, Inc.
-
-  This source code is released under the New BSD License, (the "License").
-
-  Unless required by applicable law or agreed to in writing, software
-  distributed under the License is distributed on an "AS IS" BASIS,
-  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-  See the License for the specific language governing permissions and
-  limitations under the License.
-
+  This source code is released under the 3-Clause BSD License, (see "LICENSE").
 ******************************************************************************/
 
 #include "molecularproperties.h"
@@ -22,15 +11,14 @@
 
 #include <QtCore/QStringList>
 
-namespace Avogadro {
-namespace QtPlugins {
+namespace Avogadro::QtPlugins {
 
 MolecularProperties::MolecularProperties(QObject* parent_)
   : Avogadro::QtGui::ExtensionPlugin(parent_), m_action(new QAction(this)),
     m_dialog(nullptr), m_molecule(nullptr)
 {
   m_action->setEnabled(true);
-  m_action->setText("&Molecular...");
+  m_action->setText(tr("&Molecular…"));
   connect(m_action, SIGNAL(triggered()), SLOT(showDialog()));
 }
 
@@ -72,5 +60,4 @@ void MolecularProperties::showDialog()
   m_dialog->show();
 }
 
-} // namespace QtPlugins
 } // namespace Avogadro
