@@ -1,24 +1,12 @@
 /******************************************************************************
-
   This source file is part of the Avogadro project.
-
-  Copyright 2019 Kitware, Inc.
-
-  This source code is released under the New BSD License, (the "License").
-
-  Unless required by applicable law or agreed to in writing, software
-  distributed under the License is distributed on an "AS IS" BASIS,
-  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-  See the License for the specific language governing permissions and
-  limitations under the License.
-
+  This source code is released under the 3-Clause BSD License, (see "LICENSE").
 ******************************************************************************/
 
 #include "configdialog.h"
 #include "ui_configdialog.h"
 
-namespace Avogadro {
-namespace QtPlugins {
+namespace Avogadro::QtPlugins {
 
 ConfigDialog::ConfigDialog(QWidget* parent)
   : QDialog(parent), m_ui(new Ui::ConfigDialog)
@@ -53,5 +41,4 @@ QString ConfigDialog::apiKey() const
   return m_ui->apiKey->text();
 }
 
-} // namespace QtPlugins
 } // namespace Avogadro
