@@ -1,17 +1,6 @@
 /******************************************************************************
-
   This source file is part of the Avogadro project.
-
-  Copyright 2018 Kitware, Inc.
-
-  This source code is released under the New BSD License, (the "License").
-
-  Unless required by applicable law or agreed to in writing, software
-  distributed under the License is distributed on an "AS IS" BASIS,
-  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-  See the License for the specific language governing permissions and
-  limitations under the License.
-
+  This source code is released under the 3-Clause BSD License, (see "LICENSE").
 ******************************************************************************/
 
 #include "pdfoptionsdialog.h"
@@ -19,8 +8,7 @@
 
 #include <QtCore/QSettings>
 
-namespace Avogadro {
-namespace QtPlugins {
+namespace Avogadro::QtPlugins {
 
 PdfOptionsDialog::PdfOptionsDialog(QWidget* aParent)
   : QDialog(aParent)
@@ -56,5 +44,4 @@ void PdfOptionsDialog::accept()
   QDialog::accept();
 }
 
-} // namespace QtPlugins
 } // namespace Avogadro
