@@ -1,17 +1,6 @@
 /******************************************************************************
-
   This source file is part of the Avogadro project.
-
-  Copyright 2018 Kitware, Inc.
-
-  This source code is released under the New BSD License, (the "License").
-
-  Unless required by applicable law or agreed to in writing, software
-  distributed under the License is distributed on an "AS IS" BASIS,
-  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-  See the License for the specific language governing permissions and
-  limitations under the License.
-
+  This source code is released under the 3-Clause BSD License, (see "LICENSE").
 ******************************************************************************/
 
 #include <QAction>
@@ -33,8 +22,7 @@ using Avogadro::QtGui::Molecule;
 
 using std::map;
 
-namespace Avogadro {
-namespace QtPlugins {
+namespace Avogadro::QtPlugins {
 
 using Core::Array;
 
@@ -45,7 +33,7 @@ PlotPdf::PlotPdf(QObject* parent_)
   , m_pdfOptionsDialog(new PdfOptionsDialog(qobject_cast<QWidget*>(parent())))
   , m_displayDialogAction(new QAction(this))
 {
-  m_displayDialogAction->setText(tr("Plot Pair Distribution Function..."));
+  m_displayDialogAction->setText(tr("Plot Pair Distribution Function…"));
   connect(m_displayDialogAction.data(), &QAction::triggered, this,
           &PlotPdf::displayDialog);
   m_actions.push_back(m_displayDialogAction.data());
@@ -86,7 +74,7 @@ void PlotPdf::moleculeChanged(unsigned int c)
 {
   Q_ASSERT(m_molecule == qobject_cast<Molecule*>(sender()));
 
-  Molecule::MoleculeChanges changes = static_cast<Molecule::MoleculeChanges>(c);
+  auto changes = static_cast<Molecule::MoleculeChanges>(c);
 
   if (changes & Molecule::UnitCell) {
     if (changes & Molecule::Added || changes & Molecule::Removed)
@@ -221,5 +209,4 @@ bool PlotPdf::generatePdfPattern(QtGui::Molecule& mol, PdfData& results,
   return true;
 }
 
-} // namespace QtPlugins
 } // namespace Avogadro
