@@ -1,17 +1,6 @@
 /******************************************************************************
-
   This source file is part of the Avogadro project.
-
-  Copyright 2018 Kitware, Inc.
-
-  This source code is released under the New BSD License, (the "License").
-
-  Unless required by applicable law or agreed to in writing, software
-  distributed under the License is distributed on an "AS IS" BASIS,
-  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-  See the License for the specific language governing permissions and
-  limitations under the License.
-
+  This source code is released under the 3-Clause BSD License, (see "LICENSE").
 ******************************************************************************/
 
 #include <QAction>
@@ -29,8 +18,7 @@
 
 using Avogadro::QtGui::Molecule;
 
-namespace Avogadro {
-namespace QtPlugins {
+namespace Avogadro::QtPlugins {
 
 using Core::Array;
 
@@ -40,7 +28,7 @@ PlotRmsd::PlotRmsd(QObject* parent_)
   , m_molecule(nullptr)
   , m_displayDialogAction(new QAction(this))
 {
-  m_displayDialogAction->setText(tr("Plot RMSD curve..."));
+  m_displayDialogAction->setText(tr("Plot RMSD curve…"));
   connect(m_displayDialogAction.get(), &QAction::triggered, this,
           &PlotRmsd::displayDialog);
   m_actions.push_back(m_displayDialogAction.get());
@@ -81,7 +69,7 @@ void PlotRmsd::moleculeChanged(unsigned int c)
 {
   Q_ASSERT(m_molecule == qobject_cast<Molecule*>(sender()));
 
-  Molecule::MoleculeChanges changes = static_cast<Molecule::MoleculeChanges>(c);
+  auto changes = static_cast<Molecule::MoleculeChanges>(c);
 
   if (changes & Molecule::UnitCell) {
     if (changes & Molecule::Added || changes & Molecule::Removed)
@@ -162,5 +150,4 @@ void PlotRmsd::generateRmsdPattern(RmsdData& results)
   }
 }
 
-} // namespace QtPlugins
 } // namespace Avogadro
