@@ -1,17 +1,6 @@
 /******************************************************************************
-
   This source file is part of the Avogadro project.
-
-  Copyright 2013 Kitware, Inc.
-
-  This source code is released under the New BSD License, (the "License").
-
-  Unless required by applicable law or agreed to in writing, software
-  distributed under the License is distributed on an "AS IS" BASIS,
-  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-  See the License for the specific language governing permissions and
-  limitations under the License.
-
+  This source code is released under the 3-Clause BSD License, (see "LICENSE").
 ******************************************************************************/
 
 #include "selectiontoolwidget.h"
@@ -19,13 +8,13 @@
 
 #include <QtWidgets/QColorDialog>
 
-namespace Avogadro {
-namespace QtPlugins {
+namespace Avogadro::QtPlugins {
 
 SelectionToolWidget::SelectionToolWidget(QWidget* parent)
   : QWidget(parent), m_ui(new Ui::SelectionToolWidget)
 {
   m_ui->setupUi(this);
+  setDropDown(0, 1);
   connect(m_ui->applyColorButton, SIGNAL(clicked()), this,
           SLOT(userClickedColor()));
   connect(m_ui->changeLayerDropDown, SIGNAL(currentIndexChanged(int)), this,
@@ -43,6 +32,7 @@ void SelectionToolWidget::setDropDown(size_t current, size_t max)
   for (size_t i = 0; i < max; ++i) {
     m_ui->changeLayerDropDown->addItem(QString::number(i + 1));
   }
+  m_ui->changeLayerDropDown->addItem(tr("New Layer"));
   m_ui->changeLayerDropDown->setCurrentIndex(current);
 }
 
@@ -68,5 +58,4 @@ void SelectionToolWidget::userClickedColor()
   }
 }
 
-} // namespace QtPlugins
 } // namespace Avogadro
