@@ -1,17 +1,6 @@
 /******************************************************************************
-
   This source file is part of the Avogadro project.
-
-  Copyright 2015 Kitware, Inc.
-
-  This source code is released under the New BSD License, (the "License").
-
-  Unless required by applicable law or agreed to in writing, software
-  distributed under the License is distributed on an "AS IS" BASIS,
-  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-  See the License for the specific language governing permissions and
-  limitations under the License.
-
+  This source code is released under the 3-Clause BSD License, (see "LICENSE").
 ******************************************************************************/
 
 #ifndef AVOGADRO_QTPLUGINS_VIBRATIONMODEL_H
@@ -48,7 +37,7 @@ public:
 
   void clear();
 
-  void setMolecule(QtGui::Molecule* mol) { m_molecule = mol; }
+  void setMolecule(QtGui::Molecule* mol);
 
 signals:
 
@@ -56,6 +45,7 @@ public slots:
 
 private:
   QtGui::Molecule* m_molecule;
+  bool m_hasRaman;
 };
 }
 }
