@@ -19,8 +19,7 @@ using Avogadro::QtGui::Molecule;
 using namespace msym;
 using namespace Avogadro::QtPlugins::SymmetryUtil;
 
-namespace Avogadro {
-namespace QtPlugins {
+namespace Avogadro::QtPlugins {
 
 msym_thresholds_t tight_thresholds = { // all defaults
   /*.zero =*/1.0e-3,
@@ -292,7 +291,7 @@ void SymmetryWidget::equivalenceSelectionChanged(
     m_molecule->setAtomSelected(i, false);
   }
   // this is yucky, but libmsym uses <void*> for id
-  Index selectedAtom = reinterpret_cast<Index>(a->id);
+  auto selectedAtom = reinterpret_cast<Index>(a->id);
   m_molecule->setAtomSelected(selectedAtom, true);
 
   m_molecule->emitChanged(QtGui::Molecule::Atoms);
@@ -337,14 +336,14 @@ void SymmetryWidget::setEquivalenceSets(int esl,
   m_es = es;
   m_equivalenceTreeModel->clear();
   for (int i = 0; i < esl; i++) {
-    QStandardItem* const parent = new QStandardItem;
+    auto* const parent = new QStandardItem;
     QString label = tr("Group %1").arg(QString::number(i + 1));
     parent->setText(label);
     parent->setData(i, Qt::UserRole);
     m_equivalenceTreeModel->appendRow(parent);
     const msym_equivalence_set_t* smes = &es[i];
     for (int j = 0; j < smes->length; j++) {
-      QStandardItem* const child = new QStandardItem;
+      auto* const child = new QStandardItem;
       label =
         tr("%1 %2").arg(smes->elements[j]->name).arg(QString::number(j + 1));
       child->setText(label);
@@ -362,19 +361,19 @@ void SymmetryWidget::setSubgroups(int sgl, const msym::msym_subgroup_t* sg)
   for (int i = 0; i < sgl; i++) {
     if (sg[i].order <= 2)
       continue;
-    QStandardItem* const parent = new QStandardItem;
+    auto* const parent = new QStandardItem;
     parent->setText(pointGroupSymbol(sg[i].name));
     parent->setData(i, Qt::UserRole);
     m_subgroupsTreeModel->appendRow(parent);
-    for (int j = 0; j < 2; j++) {
-      if (sg[i].generators[j] == nullptr)
+    for (auto generator : sg[i].generators) {
+      if (generator == nullptr)
         continue;
       // qDebug() << "child " << sg[i].generators[j] - m_sg << " "
       //         << sg[i].generators[j] << " " << m_sg;
-      QStandardItem* const child = new QStandardItem;
-      child->setText(pointGroupSymbol(sg[i].generators[j]->name));
+      auto* const child = new QStandardItem;
+      child->setText(pointGroupSymbol(generator->name));
 
-      child->setData(static_cast<int>(sg[i].generators[j] - m_sg),
+      child->setData(static_cast<int>(generator - m_sg),
                      Qt::UserRole);
       parent->appendRow(child);
     }
@@ -401,5 +400,4 @@ msym_thresholds_t* SymmetryWidget::getThresholds() const
   return thresholds;
 }
 
-} // namespace QtPlugins
 } // namespace Avogadro
