@@ -1,18 +1,6 @@
 /******************************************************************************
-
   This source file is part of the Avogadro project.
-
-  Copyright 2012 Kitware, Inc.
-  Copyright 2013 Tim Vandermeersch <tim.vandermeersch@gmail.com>
-
-  This source code is released under the New BSD License, (the "License").
-
-  Unless required by applicable law or agreed to in writing, software
-  distributed under the License is distributed on an "AS IS" BASIS,
-  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-  See the License for the specific language governing permissions and
-  limitations under the License.
-
+  This source code is released under the 3-Clause BSD License, (see "LICENSE").
 ******************************************************************************/
 
 #include "vanderwaalsao.h"
@@ -23,8 +11,7 @@
 #include <avogadro/rendering/geometrynode.h>
 #include <avogadro/rendering/groupnode.h>
 
-namespace Avogadro {
-namespace QtPlugins {
+namespace Avogadro::QtPlugins {
 
 using Core::Elements;
 using QtGui::PluginLayerManager;
@@ -43,9 +30,9 @@ void VanDerWaalsAO::process(const QtGui::Molecule& molecule,
                             Rendering::GroupNode& node)
 {
   // Add a sphere node to contain all of the VdW spheres.
-  GeometryNode* geometry = new GeometryNode;
+  auto* geometry = new GeometryNode;
   node.addChild(geometry);
-  AmbientOcclusionSphereGeometry* spheres = new AmbientOcclusionSphereGeometry;
+  auto* spheres = new AmbientOcclusionSphereGeometry;
   spheres->identifier().molecule = &molecule;
   spheres->identifier().type = Rendering::AtomType;
   geometry->addDrawable(spheres);
@@ -64,5 +51,4 @@ void VanDerWaalsAO::process(const QtGui::Molecule& molecule,
   }
 }
 
-} // namespace QtPlugins
 } // namespace Avogadro
