@@ -25,7 +25,7 @@ public:
   void process(const QtGui::Molecule& molecule,
                Rendering::GroupNode& node) override;
 
-  QString name() const override { return tr(m_name.c_str()); }
+  QString name() const override { return tr("Wireframe"); }
 
   QString description() const override
   {
@@ -34,6 +34,11 @@ public:
 
   QWidget* setupWidget() override;
 
+  DefaultBehavior defaultBehavior() const override
+  {
+    return DefaultBehavior::False;
+  }
+
 public slots:
   void multiBonds(bool show);
   void showHydrogens(bool show);
