@@ -1,18 +1,6 @@
 /******************************************************************************
-
   This source file is part of the Avogadro project.
-
-  Copyright 2013 Kitware, Inc.
-  Copyright 2013 Tim Vandermeersch <tim.vandermeersch@gmail.com>
-
-  This source code is released under the New BSD License, (the "License").
-
-  Unless required by applicable law or agreed to in writing, software
-  distributed under the License is distributed on an "AS IS" BASIS,
-  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-  See the License for the specific language governing permissions and
-  limitations under the License.
-
+  This source code is released under the 3-Clause BSD License, (see "LICENSE").
 ******************************************************************************/
 
 #include "ambientocclusionspheregeometry.h"
@@ -533,8 +521,7 @@ const float ao_points[] = {
 using std::cout;
 using std::endl;
 
-namespace Avogadro {
-namespace Rendering {
+namespace Avogadro::Rendering {
 
 class AmbientOcclusionRenderer
 {
@@ -1132,14 +1119,13 @@ void AmbientOcclusionSphereGeometry::update()
     int tileX = 0;
     int tileY = 0;
 
-    std::vector<size_t>::const_iterator itIndex = m_indices.begin();
-    std::vector<SphereColor>::const_iterator itSphere = m_spheres.begin();
+    auto itIndex = m_indices.begin();
+    auto itSphere = m_spheres.begin();
 
     // calculate center
     Vector3f center(Vector3f::Zero());
-    for (std::vector<SphereColor>::const_iterator i = m_spheres.begin();
-         i != m_spheres.end(); ++i)
-      center += i->center;
+    for (auto & m_sphere : m_spheres)
+      center += m_sphere.center;
     center /= static_cast<float>(nSpheres);
 
     /*
@@ -1151,10 +1137,9 @@ void AmbientOcclusionSphereGeometry::update()
 
     // calculate radius
     float radius = 0.0f;
-    for (std::vector<SphereColor>::const_iterator i = m_spheres.begin();
-         i != m_spheres.end(); ++i)
-      if ((i->center - center).norm() > radius)
-        radius = (i->center - center).norm();
+    for (auto & m_sphere : m_spheres)
+      if ((m_sphere.center - center).norm() > radius)
+        radius = (m_sphere.center - center).norm();
 
     for (unsigned int i = 0;
          itIndex != m_indices.end() && itSphere != m_spheres.end();
@@ -1354,7 +1339,7 @@ std::multimap<float, Identifier> AmbientOcclusionSphereGeometry::hits(
     id.type = m_identifier.type;
     id.index = i;
     if (id.type != InvalidType) {
-      float rootD = static_cast<float>(sqrt(D));
+      auto rootD = static_cast<float>(sqrt(D));
       float depth = std::min(std::abs(B + rootD), std::abs(B - rootD));
       result.insert(std::pair<float, Identifier>(depth, id));
     }
@@ -1377,5 +1362,4 @@ void AmbientOcclusionSphereGeometry::clear()
   m_indices.clear();
 }
 
-} // End namespace Rendering
 } // End namespace Avogadro
