@@ -1,17 +1,6 @@
 /******************************************************************************
-
   This source file is part of the Avogadro project.
-
-  Copyright 2013 Kitware, Inc.
-
-  This source code is released under the New BSD License, (the "License").
-
-  Unless required by applicable law or agreed to in writing, software
-  distributed under the License is distributed on an "AS IS" BASIS,
-  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-  See the License for the specific language governing permissions and
-  limitations under the License.
-
+  This source code is released under the 3-Clause BSD License, (see "LICENSE").
 ******************************************************************************/
 
 #include "geometryvisitor.h"
@@ -21,8 +10,7 @@
 #include "linestripgeometry.h"
 #include "spheregeometry.h"
 
-namespace Avogadro {
-namespace Rendering {
+namespace Avogadro::Rendering {
 
 GeometryVisitor::GeometryVisitor()
   : m_center(Vector3f::Zero()), m_radius(0.0f), m_dirty(false)
@@ -47,7 +35,7 @@ void GeometryVisitor::visit(SphereGeometry& geometry)
 
   Vector3f tmpCenter(Vector3f::Zero());
   // First find the center of the sphere geometry.
-  std::vector<SphereColor>::const_iterator it = spheres.begin();
+  auto it = spheres.begin();
   for (; it != spheres.end(); ++it)
     tmpCenter += it->center;
   tmpCenter /= static_cast<float>(spheres.size());
@@ -76,7 +64,7 @@ void GeometryVisitor::visit(AmbientOcclusionSphereGeometry& geometry)
 
   Vector3f tmpCenter(Vector3f::Zero());
   // First find the center of the sphere geometry.
-  std::vector<SphereColor>::const_iterator it = spheres.begin();
+  auto it = spheres.begin();
   for (; it != spheres.end(); ++it)
     tmpCenter += it->center;
   tmpCenter /= static_cast<float>(spheres.size());
@@ -134,16 +122,14 @@ void GeometryVisitor::visit(LineStripGeometry& lsg)
   m_dirty = true;
 
   Vector3f tmpCenter(Vector3f::Zero());
-  for (VertexArray::const_iterator it = verts.begin(), itEnd = verts.end();
-       it != itEnd; ++it) {
-    tmpCenter += it->vertex;
+  for (const auto & vert : verts) {
+    tmpCenter += vert.vertex;
   }
   tmpCenter /= static_cast<float>(verts.size());
 
   float tmpRadius(0.f);
-  for (VertexArray::const_iterator it = verts.begin(), itEnd = verts.end();
-       it != itEnd; ++it) {
-    float distance = (it->vertex - tmpCenter).squaredNorm();
+  for (const auto & vert : verts) {
+    float distance = (vert.vertex - tmpCenter).squaredNorm();
     if (distance > tmpRadius)
       tmpRadius = distance;
   }
@@ -201,5 +187,4 @@ void GeometryVisitor::average()
   }
 }
 
-} // End namespace Rendering
 } // End namespace Avogadro
