@@ -1,17 +1,6 @@
 /******************************************************************************
-
   This source file is part of the Avogadro project.
-
-  Copyright 2012 Kitware, Inc.
-
-  This source code is released under the New BSD License, (the "License").
-
-  Unless required by applicable law or agreed to in writing, software
-  distributed under the License is distributed on an "AS IS" BASIS,
-  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-  See the License for the specific language governing permissions and
-  limitations under the License.
-
+  This source code is released under the 3-Clause BSD License, (see "LICENSE").
 ******************************************************************************/
 
 #include "scene.h"
@@ -20,8 +9,7 @@
 
 #include <Eigen/Geometry>
 
-namespace Avogadro {
-namespace Rendering {
+namespace Avogadro::Rendering {
 
 Scene::Scene()
   : m_backgroundColor(0, 0, 0, 0), m_dirty(true), m_center(Vector3f::Zero()),
@@ -65,5 +53,4 @@ void Scene::clear()
   m_dirty = true;
 }
 
-} // End Rendering namespace
 } // End Avogadro namespace
